"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QProxyStyle(QCommonStyle):
    """
    https://doc.qt.io/qt-6/qproxystyle.html

    **Detailed Description**

    A QProxyStyle wraps a **QStyle**  (usually the default system style) for the
    purpose of dynamically overriding painting or other specific style behavior.

    The following example shows how to override the shortcut underline behavior
    on any platform:

    #include "textedit.h"
        #include <QApplication>
        #include <QProxyStyle>
    class MyProxyStyle : public **QProxyStyle**
        {
          public:
            int
    styleHint(StyleHint hint, const **QStyleOption**  *option = nullptr,
    const **QWidget**  *widget = nullptr, **QStyleHintReturn**  *returnData =
    nullptr) const override
            {
                if (hint ==
    QStyle::SH_UnderlineShortcut)
                    return 0;
                return
    **QProxyStyle** ::styleHint(hint, option, widget, returnData);
            }
    };

        int main(int argc, char **argv)
        {
    Q_INIT_RESOURCE(textedit);

            **QApplication**  a(argc, argv);
    a.setStyle(new MyProxyStyle);
            TextEdit mw;
            mw.resize(700,
    800);
            mw.show();
            //...
        }

    Warning: The **common styles**  provided by Qt will respect this hint,
    because they call **QStyle::proxy** (), but there is no guarantee that
    **QStyle::proxy** () will be called for user defined or system controlled
    styles. It would not work on a Mac, for example, where menus are handled by
    the operating system.

    When a proxy style should be set on a specific widget only, you have to make
    sure to not set the proxy on the global application style which is returned
    by **QWidget::style** (). You have to create a separate custom style for the
    widget similar to:

    ...
        auto proxy = new MyProxyStyle(**QApplication** ::style()->name());
    proxy->setParent(widget);   // take ownership to avoid memleak
    widget->setStyle(proxy);
        ...

    **See also** **QStyle** .
    """

    @typing.overload
    def __init__(self, style: typing.Optional[QStyle] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#QProxyStyle

        **QProxyStyle::QProxyStyle(QStyle * style = nullptr)**

        Constructs a QProxyStyle object for overriding behavior in the specified
        **style** , or in the default native **style**  if **style** is not
        specified.

        Ownership of **style** is transferred to QProxyStyle.
        """
        ...

    @typing.overload
    def __init__(self, key: str) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#QProxyStyle-1

        **QProxyStyle::QProxyStyle(const QString & key )**

        Constructs a QProxyStyle object for overriding behavior in the base
        style specified by style **key** , or in the current **application
        style**  if the specified style **key** is unrecognized.

        **See also** **QStyleFactory::create** ().
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#event

        **[override virtual protected] bool QProxyStyle::event(QEvent * e )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    @typing.overload
    def unpolish(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#unpolish

        **[override virtual] void QProxyStyle::unpolish(QWidget * widget )**

        Reimplements: **QCommonStyle::unpolish** (QWidget *widget).
        """
        ...

    @typing.overload
    def unpolish(self, app: QApplication) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#unpolish-1

        **[override virtual] void QProxyStyle::unpolish(QApplication * app )**

        Reimplements: **QCommonStyle::unpolish** (QApplication *application).
        """
        ...

    @typing.overload
    def polish(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#polish

        **[override virtual] void QProxyStyle::polish(QWidget * widget )**

        Reimplements: **QCommonStyle::polish** (QWidget *widget).
        """
        ...

    @typing.overload
    def polish(self, pal: QtGui.QPalette) -> QtGui.QPalette:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#polish-1

        **[override virtual] void QProxyStyle::polish(QPalette & pal )**

        Reimplements: **QCommonStyle::polish** (QPalette &pal).
        """
        ...

    @typing.overload
    def polish(self, app: QApplication) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#polish-2

        **[override virtual] void QProxyStyle::polish(QApplication * app )**

        Reimplements: **QCommonStyle::polish** (QApplication *app).
        """
        ...

    def standardPalette(self) -> QtGui.QPalette:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#standardPalette

        **[override virtual] QPalette QProxyStyle::standardPalette() const**

        Reimplements: **QStyle::standardPalette() const** .
        """
        ...

    def generatedIconPixmap(
        self, iconMode: QtGui.QIcon.Mode, pixmap: QtGui.QPixmap, opt: "QStyleOption"
    ) -> QtGui.QPixmap:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#generatedIconPixmap

        **[override virtual] QPixmap
        QProxyStyle::generatedIconPixmap(QIcon::Mode iconMode , const QPixmap &
        pixmap , const QStyleOption * opt ) const**

        Reimplements: **QCommonStyle::generatedIconPixmap(QIcon::Mode iconMode,
        const QPixmap &pixmap, const QStyleOption *opt) const** .
        """
        ...

    def standardPixmap(
        self,
        standardPixmap: QStyle.StandardPixmap,
        opt: "QStyleOption",
        widget: typing.Optional[QWidget] = ...,
    ) -> QtGui.QPixmap:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#standardPixmap

        **[override virtual] QPixmap
        QProxyStyle::standardPixmap(QStyle::StandardPixmap standardPixmap ,
        const QStyleOption * opt , const QWidget * widget = nullptr) const**

        Reimplements: **QCommonStyle::standardPixmap(QStyle::StandardPixmap sp,
        const QStyleOption *option, const QWidget *widget) const** .
        """
        ...

    def standardIcon(
        self,
        standardIcon: QStyle.StandardPixmap,
        option: typing.Optional["QStyleOption"] = ...,
        widget: typing.Optional[QWidget] = ...,
    ) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#standardIcon

        **[override virtual] QIcon
        QProxyStyle::standardIcon(QStyle::StandardPixmap standardIcon , const
        QStyleOption * option = nullptr, const QWidget * widget = nullptr)
        const**

        Reimplements: **QStyle::standardIcon(QStyle::StandardPixmap
        standardIcon, const QStyleOption *option, const QWidget *widget) const**
        .

        Returns an icon for the given **standardIcon**.

        Reimplement this slot to provide your own icons in a **QStyle**
        subclass. The **option** argument can be used to pass extra information
        required to find the appropriate icon. The **widget** argument is
        optional and can also be used to help find the icon.
        """
        ...

    def layoutSpacing(
        self,
        control1: "QSizePolicy.ControlType",
        control2: "QSizePolicy.ControlType",
        orientation: QtCore.Qt.Orientation,
        option: typing.Optional["QStyleOption"] = ...,
        widget: typing.Optional[QWidget] = ...,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#layoutSpacing

        **[override virtual] int
        QProxyStyle::layoutSpacing(QSizePolicy::ControlType control1 ,
        QSizePolicy::ControlType control2 , Qt::Orientation orientation , const
        QStyleOption * option = nullptr, const QWidget * widget = nullptr)
        const**

        Reimplements: **QCommonStyle::layoutSpacing(QSizePolicy::ControlType
        control1, QSizePolicy::ControlType control2, Qt::Orientation
        orientation, const QStyleOption *option, const QWidget *widget) const**
        .

        This slot is called by layoutSpacing() to determine the spacing that
        should be used between **control1** and **control2** in a layout.
        **orientation** specifies whether the controls are laid out side by side
        or stacked vertically. The **option** parameter can be used to pass
        extra information about the parent widget. The **widget** parameter is
        optional and can also be used if **option** is `nullptr`.

        The default implementation returns -1.

        **See also** **combinedLayoutSpacing** ().
        """
        ...

    def pixelMetric(
        self,
        metric: QStyle.PixelMetric,
        option: typing.Optional["QStyleOption"] = ...,
        widget: typing.Optional[QWidget] = ...,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#pixelMetric

        **[override virtual] int QProxyStyle::pixelMetric(QStyle::PixelMetric
        metric , const QStyleOption * option = nullptr, const QWidget * widget =
        nullptr) const**

        Reimplements: **QCommonStyle::pixelMetric(QStyle::PixelMetric m, const
        QStyleOption *opt, const QWidget *widget) const** .
        """
        ...

    def styleHint(
        self,
        hint: QStyle.StyleHint,
        option: typing.Optional["QStyleOption"] = ...,
        widget: typing.Optional[QWidget] = ...,
        returnData: typing.Optional["QStyleHintReturn"] = ...,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#styleHint

        **[override virtual] int QProxyStyle::styleHint(QStyle::StyleHint hint ,
        const QStyleOption * option = nullptr, const QWidget * widget = nullptr,
        QStyleHintReturn * returnData = nullptr) const**

        Reimplements: **QCommonStyle::styleHint(QStyle::StyleHint sh, const
        QStyleOption *opt, const QWidget *widget, QStyleHintReturn *hret)
        const** .
        """
        ...

    def hitTestComplexControl(
        self,
        control: QStyle.ComplexControl,
        option: "QStyleOptionComplex",
        pos: QtCore.QPoint,
        widget: typing.Optional[QWidget] = ...,
    ) -> QStyle.SubControl:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#hitTestComplexControl

        **[override virtual] QStyle::SubControl
        QProxyStyle::hitTestComplexControl(QStyle::ComplexControl control ,
        const QStyleOptionComplex * option , const QPoint & pos , const QWidget
        * widget = nullptr) const**

        Reimplements:
        **QCommonStyle::hitTestComplexControl(QStyle::ComplexControl cc, const
        QStyleOptionComplex *opt, const QPoint &pt, const QWidget *widget)
        const** .
        """
        ...

    def itemPixmapRect(
        self, r: QtCore.QRect, flags: int, pixmap: QtGui.QPixmap
    ) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#itemPixmapRect

        **[override virtual] QRect QProxyStyle::itemPixmapRect(const QRect & r ,
        int flags , const QPixmap & pixmap ) const**

        Reimplements: **QStyle::itemPixmapRect(const QRect &rectangle, int
        alignment, const QPixmap &pixmap) const** .
        """
        ...

    def itemTextRect(
        self,
        fm: QtGui.QFontMetrics,
        r: QtCore.QRect,
        flags: int,
        enabled: bool,
        text: str,
    ) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#itemTextRect

        **[override virtual] QRect QProxyStyle::itemTextRect(const QFontMetrics
        & fm , const QRect & r , int flags , bool enabled , const QString & text
        ) const**

        Reimplements: **QStyle::itemTextRect(const QFontMetrics &metrics, const
        QRect &rectangle, int alignment, bool enabled, const QString &text)
        const** .
        """
        ...

    def subControlRect(
        self,
        cc: QStyle.ComplexControl,
        opt: "QStyleOptionComplex",
        sc: QStyle.SubControl,
        widget: QWidget,
    ) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#subControlRect

        **[override virtual] QRect
        QProxyStyle::subControlRect(QStyle::ComplexControl cc , const
        QStyleOptionComplex * option , QStyle::SubControl sc , const QWidget *
        widget ) const**

        Reimplements: **QCommonStyle::subControlRect(QStyle::ComplexControl cc,
        const QStyleOptionComplex *opt, QStyle::SubControl sc, const QWidget
        *widget) const** .
        """
        ...

    def subElementRect(
        self, element: QStyle.SubElement, option: "QStyleOption", widget: QWidget
    ) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#subElementRect

        **[override virtual] QRect
        QProxyStyle::subElementRect(QStyle::SubElement element , const
        QStyleOption * option , const QWidget * widget ) const**

        Reimplements: **QCommonStyle::subElementRect(QStyle::SubElement sr,
        const QStyleOption *opt, const QWidget *widget) const** .
        """
        ...

    def sizeFromContents(
        self,
        type: QStyle.ContentsType,
        option: "QStyleOption",
        size: QtCore.QSize,
        widget: QWidget,
    ) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#sizeFromContents

        **[override virtual] QSize
        QProxyStyle::sizeFromContents(QStyle::ContentsType type , const
        QStyleOption * option , const QSize & size , const QWidget * widget )
        const**

        Reimplements: **QCommonStyle::sizeFromContents(QStyle::ContentsType ct,
        const QStyleOption *opt, const QSize &csz, const QWidget *widget)
        const** .
        """
        ...

    def drawItemPixmap(
        self,
        painter: QtGui.QPainter,
        rect: QtCore.QRect,
        alignment: int,
        pixmap: QtGui.QPixmap,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#drawItemPixmap

        **[override virtual] void QProxyStyle::drawItemPixmap(QPainter * painter
        , const QRect & rect , int alignment , const QPixmap & pixmap ) const**

        Reimplements: **QStyle::drawItemPixmap(QPainter *painter, const QRect
        &rectangle, int alignment, const QPixmap &pixmap) const** .
        """
        ...

    def drawItemText(
        self,
        painter: QtGui.QPainter,
        rect: QtCore.QRect,
        flags: int,
        pal: QtGui.QPalette,
        enabled: bool,
        text: str,
        textRole: QtGui.QPalette.ColorRole = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#drawItemText

        **[override virtual] void QProxyStyle::drawItemText(QPainter * painter ,
        const QRect & rect , int flags , const QPalette & pal , bool enabled ,
        const QString & text , QPalette::ColorRole textRole = QPalette::NoRole)
        const**

        Reimplements: **QStyle::drawItemText(QPainter *painter, const QRect
        &rectangle, int alignment, const QPalette &palette, bool enabled, const
        QString &text, QPalette::ColorRole textRole) const** .
        """
        ...

    def drawComplexControl(
        self,
        control: QStyle.ComplexControl,
        option: "QStyleOptionComplex",
        painter: QtGui.QPainter,
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#drawComplexControl

        **[override virtual] void
        QProxyStyle::drawComplexControl(QStyle::ComplexControl control , const
        QStyleOptionComplex * option , QPainter * painter , const QWidget *
        widget = nullptr) const**

        Reimplements: **QCommonStyle::drawComplexControl(QStyle::ComplexControl
        cc, const QStyleOptionComplex *opt, QPainter *p, const QWidget *widget)
        const** .
        """
        ...

    def drawControl(
        self,
        element: QStyle.ControlElement,
        option: "QStyleOption",
        painter: QtGui.QPainter,
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#drawControl

        **[override virtual] void
        QProxyStyle::drawControl(QStyle::ControlElement element , const
        QStyleOption * option , QPainter * painter , const QWidget * widget =
        nullptr) const**

        Reimplements: **QCommonStyle::drawControl(QStyle::ControlElement
        element, const QStyleOption *opt, QPainter *p, const QWidget *widget)
        const** .
        """
        ...

    def drawPrimitive(
        self,
        element: QStyle.PrimitiveElement,
        option: "QStyleOption",
        painter: QtGui.QPainter,
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#drawPrimitive

        **[override virtual] void
        QProxyStyle::drawPrimitive(QStyle::PrimitiveElement element , const
        QStyleOption * option , QPainter * painter , const QWidget * widget =
        nullptr) const**

        Reimplements: **QCommonStyle::drawPrimitive(QStyle::PrimitiveElement pe,
        const QStyleOption *opt, QPainter *p, const QWidget *widget) const** .
        """
        ...

    def setBaseStyle(self, style: QStyle) -> None:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#setBaseStyle

        **void QProxyStyle::setBaseStyle(QStyle * style )**

        Sets the base style that should be proxied.

        Ownership of **style** is transferred to **QProxyStyle** .

        If style is `nullptr`, a desktop-dependent style will be assigned
        automatically.

        **See also** **baseStyle** ().
        """
        ...

    def baseStyle(self) -> QStyle:
        """
        https://doc.qt.io/qt-6/qproxystyle.html#baseStyle

        **QStyle *QProxyStyle::baseStyle() const**

        Returns the proxy base style object. If no base style is set on the
        proxy style, **QProxyStyle**  will create an instance of the application
        style instead.

        **See also** **setBaseStyle** () and **QStyle** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtGui import *


class QTextDocumentFragment(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextdocumentfragment.html

    **Detailed Description**

    A QTextDocumentFragment is a fragment of rich text, that can be inserted
    into a **QTextDocument** . A document fragment can be created from a
    **QTextDocument** , from a **QTextCursor** 's selection, or from another
    document fragment. Document fragments can also be created by the static
    functions, **fromPlainText** () and **fromHtml** ().

    The contents of a document fragment can be obtained as plain text by using
    the **toPlainText** () function, or it can be obtained as HTML with
    **toHtml** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocumentfragment.html#QTextDocumentFragment

        **QTextDocumentFragment::QTextDocumentFragment()**

        Constructs an empty QTextDocumentFragment.

        **See also** **isEmpty** ().
        """
        ...

    @typing.overload
    def __init__(self, document: QTextDocument) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocumentfragment.html#QTextDocumentFragment-
        1

        **QTextDocumentFragment::QTextDocumentFragment(const QTextDocument *
        document )**

        Converts the given **document** into a QTextDocumentFragment. Note that
        the QTextDocumentFragment only stores the document contents, not meta
        information like the document's title.
        """
        ...

    @typing.overload
    def __init__(self, range: QTextCursor) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocumentfragment.html#QTextDocumentFragment-
        2

        **QTextDocumentFragment::QTextDocumentFragment(const QTextCursor &
        cursor )**

        Creates a QTextDocumentFragment from the **cursor** 's selection. If the
        cursor doesn't have a selection, the created fragment is empty.

        **See also** **isEmpty** () and **QTextCursor::selection** ().
        """
        ...

    @typing.overload
    def __init__(self, rhs: "QTextDocumentFragment") -> None:
        """
        https://doc.qt.io/qt-6/qtextdocumentfragment.html#QTextDocumentFragment-
        3

        **QTextDocumentFragment::QTextDocumentFragment(const
        QTextDocumentFragment & other )**

        Copy constructor. Creates a copy of the **other** fragment.
        """
        ...

    @staticmethod
    def fromHtml(
        html: str, resourceProvider: typing.Optional[QTextDocument] = ...
    ) -> "QTextDocumentFragment":
        """
        https://doc.qt.io/qt-6/qtextdocumentfragment.html#fromHtml

        **[static] QTextDocumentFragment QTextDocumentFragment::fromHtml(const
        QString & text , const QTextDocument * resourceProvider = nullptr)**

        Returns a **QTextDocumentFragment**  based on the arbitrary piece of
        HTML in the given **text**. The formatting is preserved as much as
        possible; for example, "<b>bold</b>" will become a document fragment
        with the text "bold" with a bold character format.

        If the provided HTML contains references to external resources such as
        imported style sheets, then they will be loaded through the
        **resourceProvider**.
        """
        ...

    @staticmethod
    def fromPlainText(plainText: str) -> "QTextDocumentFragment":
        """
        https://doc.qt.io/qt-6/qtextdocumentfragment.html#fromPlainText

        **[static] QTextDocumentFragment
        QTextDocumentFragment::fromPlainText(const QString & plainText )**

        Returns a document fragment that contains the given **plainText**.

        When inserting such a fragment into a **QTextDocument**  the current
        char format of the **QTextCursor**  used for insertion is used as format
        for the text.
        """
        ...

    def toHtml(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextdocumentfragment.html#toHtml

        **QString QTextDocumentFragment::toHtml() const**

        Returns the contents of the document fragment as HTML.

        **See also** **toPlainText** () and **QTextDocument::toHtml** ().
        """
        ...

    def toPlainText(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextdocumentfragment.html#toPlainText

        **QString QTextDocumentFragment::toPlainText() const**

        Returns the document fragment's text as plain text (i.e. with no
        formatting information).

        **See also** **toHtml** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextdocumentfragment.html#isEmpty

        **bool QTextDocumentFragment::isEmpty() const**

        Returns `true` if the fragment is empty; otherwise returns `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtPositioning import *
import enum


class QGeoSatelliteInfoSource(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qgeosatelliteinfosource.html

    **Detailed Description**

    The static function **QGeoSatelliteInfoSource::createDefaultSource** ()
    creates a default satellite data source that is appropriate for the
    platform, if one is available. Otherwise, available
    **QGeoPositionInfoSourceFactory**  plugins will be checked for one that has
    a satellite data source available.

    Call **startUpdates** () and **stopUpdates** () to start and stop regular
    updates, or **requestUpdate** () to request a single update. When an update
    is available, **satellitesInViewUpdated** () and/or
    **satellitesInUseUpdated** () will be emitted.

    If regular satellite updates are required, **setUpdateInterval** () can be
    used to specify how often these updates should be emitted. If no interval is
    specified, updates are simply provided whenever they are available. For
    example:

    // Emit updates every 10 seconds if available
        QGeoSatelliteInfoSource
    *source = QGeoSatelliteInfoSource::createDefaultSource(0);
        if (source)
    source->setUpdateInterval(10000);

    To remove an update interval that was previously set, call
    **setUpdateInterval** () with a value of 0.

    **Note:** The satellite source may have a minimum value requirement for
    update intervals, as returned by **minimumUpdateInterval** ().

    **Note:** To use this class from Android service, see **Qt Positioning on
    Android** .
    """

    class Error(enum.Enum):
        AccessError: QGeoSatelliteInfoSource = ...
        ClosedError: QGeoSatelliteInfoSource = ...
        NoError: QGeoSatelliteInfoSource = ...
        UnknownSourceError: QGeoSatelliteInfoSource = ...
        UpdateTimeoutError: QGeoSatelliteInfoSource = ...

    def __init__(self, parent: QtCore.QObject) -> None:
        ...

    def backendProperty(self, name: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#backendProperty

        **[virtual, since 6.2] QVariant
        QGeoSatelliteInfoSource::backendProperty(const QString & name ) const**

        Returns the value of the backend-specific property named **name** , if
        present. Otherwise the returned value will be invalid.

        This function was introduced in Qt 6.2.

        **See also** **setBackendProperty** .
        """
        ...

    def setBackendProperty(self, name: str, value: typing.Any) -> bool:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#setBackendProperty

        **[virtual, since 6.2] bool
        QGeoSatelliteInfoSource::setBackendProperty(const QString & name , const
        QVariant & value )**

        Sets the backend-specific property named **name** to **value**. Returns
        `true` on success, `false` otherwise. Backend-specific properties can be
        used to configure the satellite info subsystem behavior at runtime.

        This function was introduced in Qt 6.2.

        **See also** **backendProperty** .
        """
        ...

    def requestUpdate(self, timeout: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#requestUpdate

        **[pure virtual slot] void QGeoSatelliteInfoSource::requestUpdate(int
        timeout = 0)**

        Attempts to get the current satellite information and emit
        **satellitesInViewUpdated** () and **satellitesInUseUpdated** () with
        this information. If the current satellite information cannot be found
        within the given **timeout** (in milliseconds) or if **timeout** is less
        than the value returned by **minimumUpdateInterval** (), an
        **errorOccurred** () signal with **UpdateTimeoutError**  is emitted.

        If the timeout is zero, the timeout defaults to a reasonable timeout
        period as appropriate for the source.

        This does nothing if another update request is in progress. However it
        can be called even if **startUpdates** () has already been called and
        regular updates are in progress.

        **Note:** Since Qt6 this method always resets the last error to
        **NoError**  before requesting the satellite information.

        **Note:** To understand how to use this method from an Android service,
        see **Qt Positioning on Android** .
        """
        ...

    def stopUpdates(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#stopUpdates

        **[pure virtual slot] void QGeoSatelliteInfoSource::stopUpdates()**

        Stops emitting updates at regular intervals.
        """
        ...

    def startUpdates(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#startUpdates

        **[pure virtual slot] void QGeoSatelliteInfoSource::startUpdates()**

        Starts emitting updates at regular intervals. The updates will be
        provided whenever new satellite information becomes available.

        If satellite information cannot be retrieved or some other form of
        timeout has occurred the **satellitesInViewUpdated** () and
        **satellitesInUseUpdated** () signals may be emitted with empty
        parameter lists.

        **Note:** Since Qt6 this method always resets the last error to
        **NoError**  before starting the updates.

        **Note:** To understand how to use this method from an Android service,
        see **Qt Positioning on Android** .

        **See also** **satellitesInViewUpdated** () and
        **satellitesInUseUpdated** ().
        """
        ...

    def error(self) -> "QGeoSatelliteInfoSource.Error":
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#error

        **[pure virtual] QGeoSatelliteInfoSource::Error
        QGeoSatelliteInfoSource::error() const**

        Returns the last error that occurred.

        **Note:** Since Qt6 the last error is always reset when calling
        **startUpdates** () or **requestUpdate** ().
        """
        ...

    def minimumUpdateInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#minimumUpdateInterva
        l-prop

        **[read-only] minimumUpdateInterval : const int**

        This property holds the minimum time (in milliseconds) required to
        retrieve a satellite update.

        This is the minimum value accepted by **setUpdateInterval** () and
        **requestUpdate** ().

        **Access functions:**

        virtual int **minimumUpdateInterval** () const = 0
        """
        ...

    def updateInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#updateInterval-prop

        **[bindable] updateInterval : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the requested interval in milliseconds between each
        update.

        If the update interval is not set (or is set to 0) the source will
        provide updates as often as necessary.

        If the update interval is set, the source will provide updates at an
        interval as close to the requested interval as possible. If the
        requested interval is less than the **minimumUpdateInterval** (), the
        minimum interval is used instead.

        Changes to the update interval will happen as soon as is practical,
        however the time the change takes may vary between implementations.
        Whether or not the elapsed time from the previous interval is counted as
        part of the new interval is also implementation dependent.

        The default value for this property is 0.

        **Note:** Subclass implementations must call the base implementation of
        setUpdateInterval() so that updateInterval() returns the correct value.

        **Member Function Documentation**
        """
        ...

    def setUpdateInterval(self, msec: int) -> None:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#updateInterval-prop

        **[bindable] updateInterval : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the requested interval in milliseconds between each
        update.

        If the update interval is not set (or is set to 0) the source will
        provide updates as often as necessary.

        If the update interval is set, the source will provide updates at an
        interval as close to the requested interval as possible. If the
        requested interval is less than the **minimumUpdateInterval** (), the
        minimum interval is used instead.

        Changes to the update interval will happen as soon as is practical,
        however the time the change takes may vary between implementations.
        Whether or not the elapsed time from the previous interval is counted as
        part of the new interval is also implementation dependent.

        The default value for this property is 0.

        **Note:** Subclass implementations must call the base implementation of
        setUpdateInterval() so that updateInterval() returns the correct value.

        **Member Function Documentation**
        """
        ...

    def sourceName(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#sourceName

        **QString QGeoSatelliteInfoSource::sourceName() const**

        Returns the unique name of the satellite source implementation in use.

        This is the same name that can be passed to **createSource** () in order
        to create a new instance of a particular satellite source
        implementation.
        """
        ...

    @staticmethod
    def availableSources() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#availableSources

        **[static] QStringList QGeoSatelliteInfoSource::availableSources()**

        Returns a list of available source plugins, including the default system
        backend if one is available.
        """
        ...

    @typing.overload
    @staticmethod
    def createSource(
        sourceName: str, parent: QtCore.QObject
    ) -> "QGeoSatelliteInfoSource":
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#createSource

        **[static] QGeoSatelliteInfoSource
        *QGeoSatelliteInfoSource::createSource(const QString & sourceName ,
        QObject * parent )**

        Creates and returns a source with the given **parent** , by loading the
        plugin named **sourceName**.

        Returns `nullptr` if the plugin cannot be found.
        """
        ...

    @typing.overload
    @staticmethod
    def createSource(
        sourceName: str,
        parameters: typing.Dict[str, typing.Any],
        parent: QtCore.QObject,
    ) -> "QGeoSatelliteInfoSource":
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#createSource-1

        **[static, since Qt 5.14] QGeoSatelliteInfoSource
        *QGeoSatelliteInfoSource::createSource(const QString & sourceName ,
        const QVariantMap & parameters , QObject * parent )**

        Creates and returns a satellite source with the given **parent** , by
        loading the plugin named **sourceName**.

        Returns `nullptr` if the plugin cannot be found.

        This method passes **parameters** to the factory to configure the
        source.

        This function was introduced in Qt 5.14.
        """
        ...

    @typing.overload
    @staticmethod
    def createDefaultSource(parent: QtCore.QObject) -> "QGeoSatelliteInfoSource":
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#createDefaultSource

        **[static] QGeoSatelliteInfoSource
        *QGeoSatelliteInfoSource::createDefaultSource(QObject * parent )**

        Creates and returns a source with the specified **parent** that reads
        from the system's default source of satellite update information, or the
        highest priority available plugin.

        Returns `nullptr` if the system has no default satellite source, no
        valid plugins could be found or the user does not have the permission to
        access the satellite data.
        """
        ...

    @typing.overload
    @staticmethod
    def createDefaultSource(
        parameters: typing.Dict[str, typing.Any], parent: QtCore.QObject
    ) -> "QGeoSatelliteInfoSource":
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#createDefaultSource-
        1

        **[static, since Qt 5.14] QGeoSatelliteInfoSource
        *QGeoSatelliteInfoSource::createDefaultSource(const QVariantMap &
        parameters , QObject * parent )**

        Creates and returns a satellite source with the given **parent** that
        reads from the system's default sources of satellite data, or the plugin
        with the highest available priority.

        Returns `nullptr` if the system has no default satellite source, no
        valid plugins could be found or the user does not have the permission to
        access the satellite information.

        This method passes **parameters** to the factory to configure the
        source.

        This function was introduced in Qt 5.14.
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#errorOccurred

        **[signal] void
        QGeoSatelliteInfoSource::errorOccurred(QGeoSatelliteInfoSource::Error
        satelliteError )**

        This signal is emitted after an error occurred. The **satelliteError**
        parameter describes the type of error that occurred.
        """
        ...

    @property
    def satellitesInUseUpdated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#satellitesInUseUpdat
        ed

        **[signal] void QGeoSatelliteInfoSource::satellitesInUseUpdated(const
        QList<QGeoSatelliteInfo> & satellites )**

        If **startUpdates** () or **requestUpdate** () is called, this signal is
        emitted when an update is available on the number of satellites that are
        currently in use.

        These are the satellites that are used to get a "fix" - that is, those
        used to determine the current position.

        The **satellites** parameter holds the satellites currently in use.
        """
        ...

    @property
    def satellitesInViewUpdated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgeosatelliteinfosource.html#satellitesInViewUpda
        ted

        **[signal] void QGeoSatelliteInfoSource::satellitesInViewUpdated(const
        QList<QGeoSatelliteInfo> & satellites )**

        If **startUpdates** () or **requestUpdate** () is called, this signal is
        emitted when an update is available on the satellites that are currently
        in view.

        The **satellites** parameter holds the satellites currently in view.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QAbstractSpinBox(QWidget):
    """
    https://doc.qt.io/qt-6/qabstractspinbox.html

    **Detailed Description**

    The class is designed as a common super class for widgets like **QSpinBox**
    , **QDoubleSpinBox**  and **QDateTimeEdit**

    Here are the main properties of the class:

    1. **text** : The text that is displayed in the QAbstractSpinBox.
      2.
    **alignment** : The alignment of the text in the QAbstractSpinBox.
      3.
    **wrapping** : Whether the QAbstractSpinBox wraps from the minimum value to
    the maximum value and vice versa.

    QAbstractSpinBox provides a virtual **stepBy** () function that is called
    whenever the user triggers a step. This function takes an integer value to
    signify how many steps were taken. E.g. Pressing **Qt::Key_Down**  will
    trigger a call to **stepBy** (-1).

    When the user triggers a step whilst holding the **Qt::ControlModifier** ,
    QAbstractSpinBox steps by 10 instead of making a single step. This step
    modifier affects wheel events, key events and interaction with the spinbox
    buttons. Note that on macOS, Control corresponds to the Command key.

    Since Qt 5.12, **QStyle::SH_SpinBox_StepModifier**  can be used to select
    which **Qt::KeyboardModifier**  increases the step rate. **Qt::NoModifier**
    disables this feature.

    QAbstractSpinBox also provide a virtual function **stepEnabled** () to
    determine whether stepping up/down is allowed at any point. This function
    returns a bitset of **StepEnabled** .

    **See also** **QAbstractSlider** , **QSpinBox** , **QDoubleSpinBox** ,
    **QDateTimeEdit** , and **Spin Boxes Example** .
    """

    class StepType(enum.Enum):
        DefaultStepType: QAbstractSpinBox = ...
        AdaptiveDecimalStepType: QAbstractSpinBox = ...

    class CorrectionMode(enum.Enum):
        CorrectToPreviousValue: QAbstractSpinBox = ...
        CorrectToNearestValue: QAbstractSpinBox = ...

    class ButtonSymbols(enum.Enum):
        UpDownArrows: QAbstractSpinBox = ...
        PlusMinus: QAbstractSpinBox = ...
        NoButtons: QAbstractSpinBox = ...

    class StepEnabledFlag(enum.Flag):
        StepNone: QAbstractSpinBox = ...
        StepUpEnabled: QAbstractSpinBox = ...
        StepDownEnabled: QAbstractSpinBox = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#QAbstractSpinBox

        **QAbstractSpinBox::QAbstractSpinBox(QWidget * parent = nullptr)**

        Constructs an abstract spinbox with the given **parent** with default
        **wrapping** , and **alignment**  properties.
        """
        ...

    def isGroupSeparatorShown(self) -> bool:
        ...

    def setGroupSeparatorShown(self, shown: bool) -> None:
        ...

    def inputMethodQuery(self, a0: QtCore.Qt.InputMethodQuery) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#inputMethodQuery

        **[override virtual] QVariant
        QAbstractSpinBox::inputMethodQuery(Qt::InputMethodQuery query ) const**

        Reimplements: **QWidget::inputMethodQuery(Qt::InputMethodQuery query)
        const** .
        """
        ...

    def keyboardTracking(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#keyboardTracking-prop

        **keyboardTracking : bool**

        This property holds whether keyboard tracking is enabled for the
        spinbox.

        If keyboard tracking is enabled (the default), the spinbox emits the
        valueChanged() and textChanged() signals while the new value is being
        entered from the keyboard.

        E.g. when the user enters the value 600 by typing 6, 0, and 0, the
        spinbox emits 3 signals with the values 6, 60, and 600 respectively.

        If keyboard tracking is disabled, the spinbox doesn't emit the
        valueChanged() and textChanged() signals while typing. It emits the
        signals later, when the return key is pressed, when keyboard focus is
        lost, or when other spinbox functionality is used, e.g. pressing an
        arrow key.

        **Access functions:**

        bool **keyboardTracking** () const
        void **setKeyboardTracking** (bool
        **kt** )
        """
        ...

    def setKeyboardTracking(self, kt: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#keyboardTracking-prop

        **keyboardTracking : bool**

        This property holds whether keyboard tracking is enabled for the
        spinbox.

        If keyboard tracking is enabled (the default), the spinbox emits the
        valueChanged() and textChanged() signals while the new value is being
        entered from the keyboard.

        E.g. when the user enters the value 600 by typing 6, 0, and 0, the
        spinbox emits 3 signals with the values 6, 60, and 600 respectively.

        If keyboard tracking is disabled, the spinbox doesn't emit the
        valueChanged() and textChanged() signals while typing. It emits the
        signals later, when the return key is pressed, when keyboard focus is
        lost, or when other spinbox functionality is used, e.g. pressing an
        arrow key.

        **Access functions:**

        bool **keyboardTracking** () const
        void **setKeyboardTracking** (bool
        **kt** )
        """
        ...

    def isAccelerated(self) -> bool:
        ...

    def setAccelerated(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#accelerated-prop

        **accelerated : bool**

        This property holds whether the spin box will accelerate the frequency
        of the steps when pressing the step Up/Down buttons.

        If enabled the spin box will increase/decrease the value faster the
        longer you hold the button down.

        **Access functions:**

        bool **isAccelerated** () const
        void **setAccelerated** (bool **on** )
        """
        ...

    def hasAcceptableInput(self) -> bool:
        ...

    def correctionMode(self) -> "QAbstractSpinBox.CorrectionMode":
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#correctionMode-prop

        **correctionMode : CorrectionMode**

        This property holds the mode to correct an **Intermediate**  value if
        editing finishes

        The default mode is **QAbstractSpinBox::CorrectToPreviousValue** .

        **Access functions:**

        QAbstractSpinBox::CorrectionMode **correctionMode** () const
        void
        **setCorrectionMode** (QAbstractSpinBox::CorrectionMode **cm** )

        **See also** **acceptableInput** , **validate** (), and **fixup** ().
        """
        ...

    def setCorrectionMode(self, cm: "QAbstractSpinBox.CorrectionMode") -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#correctionMode-prop

        **correctionMode : CorrectionMode**

        This property holds the mode to correct an **Intermediate**  value if
        editing finishes

        The default mode is **QAbstractSpinBox::CorrectToPreviousValue** .

        **Access functions:**

        QAbstractSpinBox::CorrectionMode **correctionMode** () const
        void
        **setCorrectionMode** (QAbstractSpinBox::CorrectionMode **cm** )

        **See also** **acceptableInput** , **validate** (), and **fixup** ().
        """
        ...

    def initStyleOption(self, option: "QStyleOptionSpinBox") -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#initStyleOption

        **[virtual protected] void
        QAbstractSpinBox::initStyleOption(QStyleOptionSpinBox * option ) const**

        Initialize **option** with the values from this **QSpinBox** . This
        method is useful for subclasses when they need a **QStyleOptionSpinBox**
        , but don't want to fill in all the information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def stepEnabled(self) -> "QAbstractSpinBox.StepEnabledFlag":
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#stepEnabled

        **[virtual protected] QAbstractSpinBox::StepEnabled
        QAbstractSpinBox::stepEnabled() const**

        Virtual function that determines whether stepping up and down is legal
        at any given time.

        The up arrow will be painted as disabled unless (stepEnabled() &
        **StepUpEnabled** ) != 0.

        The default implementation will return (**StepUpEnabled** |
        **StepDownEnabled** ) if wrapping is turned on. Else it will return
        **StepDownEnabled**  if value is > minimum() or'ed with
        **StepUpEnabled**  if value < maximum().

        If you subclass **QAbstractSpinBox**  you will need to reimplement this
        function.

        **See also** **QSpinBox::minimum** (), **QSpinBox::maximum** (), and
        **wrapping** ().
        """
        ...

    def setLineEdit(self, e: "QLineEdit") -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#setLineEdit

        **[protected] void QAbstractSpinBox::setLineEdit(QLineEdit * lineEdit
        )**

        Sets the line edit of the spinbox to be **lineEdit** instead of the
        current line edit widget. **lineEdit** cannot be `nullptr`.

        **QAbstractSpinBox**  takes ownership of the new **lineEdit**

        If **QLineEdit::validator** () for the **lineEdit** returns `nullptr`,
        the internal validator of the spinbox will be set on the line edit.

        **See also** **lineEdit** ().
        """
        ...

    def lineEdit(self) -> "QLineEdit":
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#lineEdit

        **[protected] QLineEdit *QAbstractSpinBox::lineEdit() const**

        This function returns a pointer to the line edit of the spin box.

        **See also** **setLineEdit** ().
        """
        ...

    def showEvent(self, e: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#showEvent

        **[override virtual protected] void
        QAbstractSpinBox::showEvent(QShowEvent * event )**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#paintEvent

        **[override virtual protected] void
        QAbstractSpinBox::paintEvent(QPaintEvent * event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def timerEvent(self, e: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#timerEvent

        **[override virtual protected] void
        QAbstractSpinBox::timerEvent(QTimerEvent * event )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def mouseMoveEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#mouseMoveEvent

        **[override virtual protected] void
        QAbstractSpinBox::mouseMoveEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mouseReleaseEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#mouseReleaseEvent

        **[override virtual protected] void
        QAbstractSpinBox::mouseReleaseEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#mousePressEvent

        **[override virtual protected] void
        QAbstractSpinBox::mousePressEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def hideEvent(self, e: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#hideEvent

        **[override virtual protected] void
        QAbstractSpinBox::hideEvent(QHideEvent * event )**

        Reimplements: **QWidget::hideEvent** (QHideEvent *event).
        """
        ...

    def closeEvent(self, e: QtGui.QCloseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#closeEvent

        **[override virtual protected] void
        QAbstractSpinBox::closeEvent(QCloseEvent * event )**

        Reimplements: **QWidget::closeEvent** (QCloseEvent *event).
        """
        ...

    def changeEvent(self, e: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#changeEvent

        **[override virtual protected] void QAbstractSpinBox::changeEvent(QEvent
        * event )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def contextMenuEvent(self, e: QtGui.QContextMenuEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#contextMenuEvent

        **[override virtual protected] void
        QAbstractSpinBox::contextMenuEvent(QContextMenuEvent * event )**

        Reimplements: **QWidget::contextMenuEvent** (QContextMenuEvent *event).
        """
        ...

    def focusOutEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#focusOutEvent

        **[override virtual protected] void
        QAbstractSpinBox::focusOutEvent(QFocusEvent * event )**

        Reimplements: **QWidget::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusInEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#focusInEvent

        **[override virtual protected] void
        QAbstractSpinBox::focusInEvent(QFocusEvent * event )**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def wheelEvent(self, e: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#wheelEvent

        **[override virtual protected] void
        QAbstractSpinBox::wheelEvent(QWheelEvent * event )**

        Reimplements: **QWidget::wheelEvent** (QWheelEvent *event).
        """
        ...

    def keyReleaseEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#keyReleaseEvent

        **[override virtual protected] void
        QAbstractSpinBox::keyReleaseEvent(QKeyEvent * event )**

        Reimplements: **QWidget::keyReleaseEvent** (QKeyEvent *event).
        """
        ...

    def keyPressEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#keyPressEvent

        **[override virtual protected] void
        QAbstractSpinBox::keyPressEvent(QKeyEvent * event )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).

        This function handles keyboard input.

        The following keys are handled specifically:

        Enter/ReturnThis will reinterpret the text and emit a signal even if the
        value has not changed since last time a signal was emitted.
        UpThis
        will invoke **stepBy** (1)
        DownThis will invoke **stepBy** (-1)
        Page
        upThis will invoke **stepBy** (10)
        Page downThis will invoke
        **stepBy** (-10)

        **See also** **stepBy** ().
        """
        ...

    def resizeEvent(self, e: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#resizeEvent

        **[override virtual protected] void
        QAbstractSpinBox::resizeEvent(QResizeEvent * event )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#clear

        **[virtual slot] void QAbstractSpinBox::clear()**

        Clears the lineedit of all text but prefix and suffix.
        """
        ...

    def selectAll(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#selectAll

        **[slot] void QAbstractSpinBox::selectAll()**

        Selects all the text in the spinbox except the prefix and suffix.
        """
        ...

    def stepDown(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#stepDown

        **[slot] void QAbstractSpinBox::stepDown()**

        Steps down by one linestep Calling this slot is analogous to calling
        **stepBy** (-1);

        **See also** **stepBy** () and **stepUp** ().
        """
        ...

    def stepUp(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#stepUp

        **[slot] void QAbstractSpinBox::stepUp()**

        Steps up by one linestep Calling this slot is analogous to calling
        **stepBy** (1);

        **See also** **stepBy** () and **stepDown** ().
        """
        ...

    def stepBy(self, steps: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#stepBy

        **[virtual] void QAbstractSpinBox::stepBy(int steps )**

        Virtual function that is called whenever the user triggers a step. The
        **steps** parameter indicates how many steps were taken. For example,
        pressing `Qt::Key_Down` will trigger a call to `stepBy(-1)`, whereas
        pressing `Qt::Key_PageUp` will trigger a call to `stepBy(10)`.

        If you subclass `QAbstractSpinBox` you must reimplement this function.
        Note that this function is called even if the resulting value will be
        outside the bounds of minimum and maximum. It's this function's job to
        handle these situations.

        **See also** **stepUp** (), **stepDown** (), and **keyPressEvent** ().
        """
        ...

    def fixup(self, input: str) -> str:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#fixup

        **[virtual] void QAbstractSpinBox::fixup(QString & input ) const**

        This virtual function is called by the **QAbstractSpinBox**  if the
        **input** is not validated to **QValidator::Acceptable**  when Return is
        pressed or **interpretText** () is called. It will try to change the
        text so it is valid. Reimplemented in the various subclasses.
        """
        ...

    def validate(
        self, input: str, pos: int
    ) -> typing.Tuple[QtGui.QValidator.State, str, int]:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#validate

        **[virtual] QValidator::State QAbstractSpinBox::validate(QString & input
        , int & pos ) const**

        This virtual function is called by the **QAbstractSpinBox**  to
        determine whether **input** is valid. The **pos** parameter indicates
        the position in the string. Reimplemented in the various subclasses.
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#event

        **[override virtual] bool QAbstractSpinBox::event(QEvent * event )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def interpretText(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#interpretText

        **void QAbstractSpinBox::interpretText()**

        This function interprets the text of the spin box. If the value has
        changed since last interpretation it will emit signals.
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#minimumSizeHint

        **[override virtual] QSize QAbstractSpinBox::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#sizeHint

        **[override virtual] QSize QAbstractSpinBox::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    def hasFrame(self) -> bool:
        ...

    def setFrame(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#frame-prop

        **frame : bool**

        This property holds whether the spin box draws itself with a frame

        If enabled (the default) the spin box draws itself inside a frame,
        otherwise the spin box draws itself without any frame.

        **Access functions:**

        bool **hasFrame** () const
        void **setFrame** (bool)
        """
        ...

    def alignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#alignment-prop

        **alignment : Qt::Alignment**

        This property holds the alignment of the spin box

        Possible Values are **Qt::AlignLeft** , **Qt::AlignRight** , and
        **Qt::AlignHCenter** .

        By default, the alignment is **Qt::AlignLeft**

        Attempting to set the alignment to an illegal flag combination does
        nothing.

        **Access functions:**

        Qt::Alignment **alignment** () const
        void **setAlignment**
        (Qt::Alignment **flag** )

        **See also** **Qt::Alignment** .
        """
        ...

    def setAlignment(self, flag: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#alignment-prop

        **alignment : Qt::Alignment**

        This property holds the alignment of the spin box

        Possible Values are **Qt::AlignLeft** , **Qt::AlignRight** , and
        **Qt::AlignHCenter** .

        By default, the alignment is **Qt::AlignLeft**

        Attempting to set the alignment to an illegal flag combination does
        nothing.

        **Access functions:**

        Qt::Alignment **alignment** () const
        void **setAlignment**
        (Qt::Alignment **flag** )

        **See also** **Qt::Alignment** .
        """
        ...

    def isReadOnly(self) -> bool:
        ...

    def setReadOnly(self, r: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#readOnly-prop

        **readOnly : bool**

        This property holds whether the spin box is read only.

        In read-only mode, the user can still copy the text to the clipboard, or
        drag and drop the text; but cannot edit it.

        The **QLineEdit**  in the **QAbstractSpinBox**  does not show a cursor
        in read-only mode.

        **Access functions:**

        bool **isReadOnly** () const
        void **setReadOnly** (bool **r** )

        **See also** **QLineEdit::readOnly** .
        """
        ...

    def setWrapping(self, w: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#wrapping-prop

        **wrapping : bool**

        This property holds whether the spin box is circular.

        If wrapping is true stepping up from maximum() value will take you to
        the minimum() value and vice versa. Wrapping only make sense if you have
        minimum() and maximum() values set.

        **QSpinBox**  *spinBox = new **QSpinBox** (this);
        spinBox->setRange(0, 100);
            spinBox->setWrapping(true);
        spinBox->setValue(100);
            spinBox->stepBy(1);
            // value is 0

        **Access functions:**

        bool **wrapping** () const
        void **setWrapping** (bool **w** )

        **See also** **QSpinBox::minimum** () and **QSpinBox::maximum** ().

        **Member Function Documentation**
        """
        ...

    def wrapping(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#wrapping-prop

        **wrapping : bool**

        This property holds whether the spin box is circular.

        If wrapping is true stepping up from maximum() value will take you to
        the minimum() value and vice versa. Wrapping only make sense if you have
        minimum() and maximum() values set.

        **QSpinBox**  *spinBox = new **QSpinBox** (this);
        spinBox->setRange(0, 100);
            spinBox->setWrapping(true);
        spinBox->setValue(100);
            spinBox->stepBy(1);
            // value is 0

        **Access functions:**

        bool **wrapping** () const
        void **setWrapping** (bool **w** )

        **See also** **QSpinBox::minimum** () and **QSpinBox::maximum** ().

        **Member Function Documentation**
        """
        ...

    def setSpecialValueText(self, s: str) -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#specialValueText-prop

        **specialValueText : QString**

        This property holds the special-value text

        If set, the spin box will display this text instead of a numeric value
        whenever the current value is equal to minimum(). Typical use is to
        indicate that this choice has a special (default) meaning.

        For example, if your spin box allows the user to choose a scale factor
        (or zoom level) for displaying an image, and your application is able to
        automatically choose one that will enable the image to fit completely
        within the display window, you can set up the spin box like this:

        **QSpinBox**  *zoomSpinBox = new **QSpinBox** ;
        zoomSpinBox->setRange(0, 1000);
                zoomSpinBox->setSingleStep(10);
        zoomSpinBox->setSuffix("%");
        zoomSpinBox->setSpecialValueText(tr("Automatic"));
        zoomSpinBox->setValue(100);

        The user will then be able to choose a scale from 1% to 1000% or select
        "Auto" to leave it up to the application to choose. Your code must then
        interpret the spin box value of 0 as a request from the user to scale
        the image to fit inside the window.

        All values are displayed with the prefix and suffix (if set), **except**
        for the special value, which only shows the special value text. This
        special text is passed in the **QSpinBox::textChanged** () signal that
        passes a **QString** .

        To turn off the special-value text display, call this function with an
        empty string. The default is no special-value text, i.e. the numeric
        value is shown as usual.

        If no special-value text is set, specialValueText() returns an empty
        string.

        **Access functions:**

        QString **specialValueText** () const
        void **setSpecialValueText**
        (const QString & **txt** )
        """
        ...

    def specialValueText(self) -> str:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#specialValueText-prop

        **specialValueText : QString**

        This property holds the special-value text

        If set, the spin box will display this text instead of a numeric value
        whenever the current value is equal to minimum(). Typical use is to
        indicate that this choice has a special (default) meaning.

        For example, if your spin box allows the user to choose a scale factor
        (or zoom level) for displaying an image, and your application is able to
        automatically choose one that will enable the image to fit completely
        within the display window, you can set up the spin box like this:

        **QSpinBox**  *zoomSpinBox = new **QSpinBox** ;
        zoomSpinBox->setRange(0, 1000);
                zoomSpinBox->setSingleStep(10);
        zoomSpinBox->setSuffix("%");
        zoomSpinBox->setSpecialValueText(tr("Automatic"));
        zoomSpinBox->setValue(100);

        The user will then be able to choose a scale from 1% to 1000% or select
        "Auto" to leave it up to the application to choose. Your code must then
        interpret the spin box value of 0 as a request from the user to scale
        the image to fit inside the window.

        All values are displayed with the prefix and suffix (if set), **except**
        for the special value, which only shows the special value text. This
        special text is passed in the **QSpinBox::textChanged** () signal that
        passes a **QString** .

        To turn off the special-value text display, call this function with an
        empty string. The default is no special-value text, i.e. the numeric
        value is shown as usual.

        If no special-value text is set, specialValueText() returns an empty
        string.

        **Access functions:**

        QString **specialValueText** () const
        void **setSpecialValueText**
        (const QString & **txt** )
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#text-prop

        **[read-only] text : const QString**

        This property holds the spin box's text, including any prefix and suffix

        There is no default text.

        **Access functions:**

        QString **text** () const
        """
        ...

    def setButtonSymbols(self, bs: "QAbstractSpinBox.ButtonSymbols") -> None:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#buttonSymbols-prop

        **buttonSymbols : ButtonSymbols**

        This property holds the current button symbol mode

        The possible values can be either `UpDownArrows` or `PlusMinus`. The
        default is `UpDownArrows`.

        Note that some styles might render **PlusMinus**  and **UpDownArrows**
        identically.

        **Access functions:**

        QAbstractSpinBox::ButtonSymbols **buttonSymbols** () const
        void
        **setButtonSymbols** (QAbstractSpinBox::ButtonSymbols **bs** )

        **See also** **ButtonSymbols** .
        """
        ...

    def buttonSymbols(self) -> "QAbstractSpinBox.ButtonSymbols":
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#buttonSymbols-prop

        **buttonSymbols : ButtonSymbols**

        This property holds the current button symbol mode

        The possible values can be either `UpDownArrows` or `PlusMinus`. The
        default is `UpDownArrows`.

        Note that some styles might render **PlusMinus**  and **UpDownArrows**
        identically.

        **Access functions:**

        QAbstractSpinBox::ButtonSymbols **buttonSymbols** () const
        void
        **setButtonSymbols** (QAbstractSpinBox::ButtonSymbols **bs** )

        **See also** **ButtonSymbols** .
        """
        ...

    @property
    def editingFinished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractspinbox.html#editingFinished

        **[signal] void QAbstractSpinBox::editingFinished()**

        This signal is emitted editing is finished. This happens when the
        spinbox loses focus and when enter is pressed.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QWindow(QtCore.QObject, QSurface):
    """
    https://doc.qt.io/qt-6/qwindow.html

    **Detailed Description**

    A window that is supplied a parent becomes a native child window of their
    parent window.

    An application will typically use **QWidget**  or **QQuickView**  for its
    UI, and not QWindow directly. Still, it is possible to render directly to a
    QWindow with **QBackingStore**  or **QOpenGLContext** , when wanting to keep
    dependencies to a minimum or when wanting to use OpenGL directly. The
    **Raster Window Example**  and **OpenGL Window Example**  are useful
    reference examples for how to render to a QWindow using either approach.

    **Resource Management**

    Windows can potentially use a lot of memory. A usual measurement is width
    times height times color depth. A window might also include multiple buffers
    to support double and triple buffering, as well as depth and stencil
    buffers. To release a window's memory resources, call the **destroy** ()
    function.

    **Content Orientation**

    QWindow has **reportContentOrientationChange** () that can be used to
    specify the layout of the window contents in relation to the screen. The
    content orientation is simply a hint to the windowing system about which
    orientation the window contents are in. It's useful when you wish to keep
    the same window size, but rotate the contents instead, especially when doing
    rotation animations between different orientations. The windowing system
    might use this value to determine the layout of system popups or dialogs.

    **Visibility and Windowing System Exposure**

    By default, the window is not visible, and you must call **setVisible**
    (true), or **show** () or similar to make it visible. To make a window
    hidden again, call **setVisible** (false) or **hide** (). The visible
    property describes the state the application wants the window to be in.
    Depending on the underlying system, a visible window might still not be
    shown on the screen. It could, for instance, be covered by other opaque
    windows or moved outside the physical area of the screen. On windowing
    systems that have exposure notifications, the **isExposed** () accessor
    describes whether the window should be treated as directly visible on
    screen. The **exposeEvent** () function is called whenever an area of the
    window is invalidated, for example due to the exposure in the windowing
    system changing. On windowing systems that do not make this information
    visible to the application, **isExposed** () will simply return the same
    value as **isVisible** ().

    **QWindow::Visibility**  queried through **visibility** () is a convenience
    API combining the functions of visible() and **windowStates** ().

    **Rendering**

    There are two Qt APIs that can be used to render content into a window,
    **QBackingStore**  for rendering with a **QPainter**  and flushing the
    contents to a window with type **QSurface::RasterSurface** , and
    **QOpenGLContext**  for rendering with OpenGL to a window with type
    **QSurface::OpenGLSurface** .

    The application can start rendering as soon as **isExposed** () returns
    `true`, and can keep rendering until it **isExposed** () returns `false`. To
    find out when **isExposed** () changes, reimplement **exposeEvent** (). The
    window will always get a resize event before the first expose event.

    **Initial Geometry**

    If the window's width and height are left uninitialized, the window will get
    a reasonable default geometry from the platform window. If the position is
    left uninitialized, then the platform window will allow the windowing system
    to position the window. For example on X11, the window manager usually does
    some kind of smart positioning to try to avoid having new windows completely
    obscure existing windows. However **setGeometry** () initializes both the
    position and the size, so if you want a fixed size but an automatic
    position, you should call **resize** () or **setWidth** () and **setHeight**
    () instead.
    """

    class Visibility(enum.Enum):
        Hidden: QWindow = ...
        AutomaticVisibility: QWindow = ...
        Windowed: QWindow = ...
        Minimized: QWindow = ...
        Maximized: QWindow = ...
        FullScreen: QWindow = ...

    class AncestorMode(enum.Enum):
        ExcludeTransients: QWindow = ...
        IncludeTransients: QWindow = ...

    @typing.overload
    def __init__(self, screen: typing.Optional["QScreen"] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#QWindow

        **QWindow::QWindow(QScreen * targetScreen = nullptr)**

        Creates a window as a top level on the **targetScreen**.

        The window is not shown until **setVisible** (true), **show** (), or
        similar is called.

        **See also** **setScreen** ().
        """
        ...

    @typing.overload
    def __init__(self, parent: "QWindow") -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#QWindow-1

        **QWindow::QWindow(QWindow * parent )**

        Creates a window as a child of the given **parent** window.

        The window will be embedded inside the parent window, its coordinates
        relative to the parent.

        The screen is inherited from the parent.

        **See also** **setParent** ().
        """
        ...

    def nativeEvent(
        self, eventType: QtCore.QByteArray, message: PyQt6.sip.voidptr
    ) -> typing.Tuple[bool, PyQt6.sip.voidptr]:
        """
        https://doc.qt.io/qt-6/qwindow.html#nativeEvent

        **[virtual protected] bool QWindow::nativeEvent(const QByteArray &
        eventType , void * message , qintptr * result )**

        Override this to handle platform dependent events. Will be given
        **eventType** , **message** and **result**.

        This might make your application non-portable.

        Should return true only if the event was handled.
        """
        ...

    def closeEvent(self, a0: QCloseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#closeEvent

        **[virtual protected] void QWindow::closeEvent(QCloseEvent * ev )**

        Override this to handle close events ( **ev** ).

        The function is called when the window is requested to close. Call
        **QEvent::ignore** () on the event if you want to prevent the window
        from being closed.

        **See also** **close** ().
        """
        ...

    def paintEvent(self, a0: QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#paintEvent

        **[virtual protected, since 6.0] void QWindow::paintEvent(QPaintEvent *
        ev )**

        The paint event ( **ev** ) is sent by the window system whenever an area
        of the window needs a repaint, for example when initially showing the
        window, or due to parts of the window being uncovered by moving another
        window.

        The application is expected to render into the window in response to the
        paint event, regardless of the exposed state of the window. For example,
        a paint event may be sent before the window is exposed, to prepare it
        for showing to the user.

        This function was introduced in Qt 6.0.

        **See also** **exposeEvent** ().
        """
        ...

    def startSystemMove(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#startSystemMove

        **[slot, since 5.15] bool QWindow::startSystemMove()**

        Start a system-specific move operation

        Calling this will start an interactive move operation on the window by
        platforms that support it. The actual behavior may vary depending on the
        platform. Usually, it will make the window follow the mouse cursor until
        a mouse button is released.

        On platforms that support it, this method of moving windows is preferred
        over `setPosition`, because it allows a more native look-and-feel of
        moving windows, e.g. letting the window manager snap this window against
        other windows, or special tiling or resizing behavior with animations
        when dragged to the edge of the screen. Furthermore, on some platforms
        such as Wayland, `setPosition` is not supported, so this is the only way
        the application can influence its position.

        Returns true if the operation was supported by the system.

        This function was introduced in Qt 5.15.
        """
        ...

    def startSystemResize(self, edges: QtCore.Qt.Edge) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#startSystemResize

        **[slot, since 5.15] bool QWindow::startSystemResize(Qt::Edges edges )**

        Start a system-specific resize operation

        Calling this will start an interactive resize operation on the window by
        platforms that support it. The actual behavior may vary depending on the
        platform. Usually, it will make the window resize so that its edge
        follows the mouse cursor.

        On platforms that support it, this method of resizing windows is
        preferred over `setGeometry`, because it allows a more native look and
        feel of resizing windows, e.g. letting the window manager snap this
        window against other windows, or special resizing behavior with
        animations when dragged to the edge of the screen.

        **edges** should either be a single edge, or two adjacent edges (a
        corner). Other values are not allowed.

        Returns true if the operation was supported by the system.

        This function was introduced in Qt 5.15.
        """
        ...

    def setWindowStates(self, states: QtCore.Qt.WindowState) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setWindowStates

        **[since 5.10] void QWindow::setWindowStates(Qt::WindowStates state )**

        set the screen-occupation state of the window

        The window **state** represents whether the window appears in the
        windowing system as maximized, minimized and/or fullscreen.

        The window can be in a combination of several states. For example, if
        the window is both minimized and maximized, the window will appear
        minimized, but clicking on the task bar entry will restore it to the
        maximized state.

        The enum value **Qt::WindowActive**  should not be set.

        This function was introduced in Qt 5.10.

        **See also** **windowStates** (), **showNormal** (), **showFullScreen**
        (), **showMinimized** (), and **showMaximized** ().
        """
        ...

    def windowStates(self) -> QtCore.Qt.WindowState:
        """
        https://doc.qt.io/qt-6/qwindow.html#windowStates

        **[since 5.10] Qt::WindowStates QWindow::windowStates() const**

        the screen-occupation state of the window

        The window can be in a combination of several states. For example, if
        the window is both minimized and maximized, the window will appear
        minimized, but clicking on the task bar entry will restore it to the
        maximized state.

        This function was introduced in Qt 5.10.

        **See also** **setWindowStates** ().
        """
        ...

    def setFlag(self, a0: QtCore.Qt.WindowType, on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setFlag

        **[since 5.9] void QWindow::setFlag(Qt::WindowType flag , bool on =
        true)**

        Sets the window flag **flag** on this window if **on** is true;
        otherwise clears the flag.

        This function was introduced in Qt 5.9.

        **See also** **setFlags** (), **flags** (), and **type** ().
        """
        ...

    @staticmethod
    def fromWinId(id: PyQt6.sip.voidptr) -> "QWindow":
        """
        https://doc.qt.io/qt-6/qwindow.html#fromWinId

        **[static] QWindow *QWindow::fromWinId(WId id )**

        Creates a local representation of a window created by another process or
        by using native libraries below Qt.

        Given the handle **id** to a native window, this method creates a
        **QWindow**  object which can be used to represent the window when
        invoking methods like **setParent** () and **setTransientParent** ().

        This can be used, on platforms which support it, to embed a **QWindow**
        inside a native window, or to embed a native window inside a **QWindow**
        .

        If foreign windows are not supported or embedding the native window
        failed in the platform plugin, this function returns `nullptr`.

        **Note:** The resulting **QWindow**  should not be used to manipulate
        the underlying native window (besides re-parenting), or to observe state
        changes of the native window. Any support for these kind of operations
        is incidental, highly platform dependent and untested.

        **See also** **setParent** ().
        """
        ...

    def mask(self) -> "QRegion":
        """
        https://doc.qt.io/qt-6/qwindow.html#mask

        **QRegion QWindow::mask() const**

        Returns the mask set on the window.

        The mask is a hint to the windowing system that the application does not
        want to receive mouse or touch input outside the given region.

        **See also** **setMask** ().
        """
        ...

    def setMask(self, region: "QRegion") -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setMask

        **void QWindow::setMask(const QRegion & region )**

        Sets the mask of the window.

        The mask is a hint to the windowing system that the application does not
        want to receive mouse or touch input outside the given **region**.

        The window manager may or may not choose to display any areas of the
        window not included in the mask, thus it is the application's
        responsibility to clear to transparent the areas that are not part of
        the mask.

        **See also** **mask** ().
        """
        ...

    def opacity(self) -> float:
        """
        https://doc.qt.io/qt-6/qwindow.html#opacity-prop

        **[since 5.1] opacity : qreal**

        This property holds the opacity of the window in the windowing system.

        If the windowing system supports window opacity, this can be used to
        fade the window in and out, or to make it semitransparent.

        A value of 1.0 or above is treated as fully opaque, whereas a value of
        0.0 or below is treated as fully transparent. Values inbetween represent
        varying levels of translucency between the two extremes.

        The default value is 1.0.

        This property was introduced in Qt 5.1.

        **Access functions:**

        qreal **opacity** () const
        void **setOpacity** (qreal **level** )

        **Notifier signal:**

        void **opacityChanged** (qreal **opacity** )
        """
        ...

    def setVisibility(self, v: "QWindow.Visibility") -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#visibility-prop

        **[since 5.1] visibility : Visibility**

        This property holds the screen-occupation state of the window

        Visibility is whether the window should appear in the windowing system
        as normal, minimized, maximized, fullscreen or hidden.

        To set the visibility to **AutomaticVisibility**  means to give the
        window a default visible state, which might be fullscreen or windowed
        depending on the platform. When reading the visibility property you will
        always get the actual state, never **AutomaticVisibility** .

        This property was introduced in Qt 5.1.

        **Access functions:**

        QWindow::Visibility **visibility** () const
        void **setVisibility**
        (QWindow::Visibility **v** )

        **Notifier signal:**

        void **visibilityChanged** (QWindow::Visibility **visibility** )
        """
        ...

    def visibility(self) -> "QWindow.Visibility":
        """
        https://doc.qt.io/qt-6/qwindow.html#visibility-prop

        **[since 5.1] visibility : Visibility**

        This property holds the screen-occupation state of the window

        Visibility is whether the window should appear in the windowing system
        as normal, minimized, maximized, fullscreen or hidden.

        To set the visibility to **AutomaticVisibility**  means to give the
        window a default visible state, which might be fullscreen or windowed
        depending on the platform. When reading the visibility property you will
        always get the actual state, never **AutomaticVisibility** .

        This property was introduced in Qt 5.1.

        **Access functions:**

        QWindow::Visibility **visibility** () const
        void **setVisibility**
        (QWindow::Visibility **v** )

        **Notifier signal:**

        void **visibilityChanged** (QWindow::Visibility **visibility** )
        """
        ...

    def tabletEvent(self, a0: QTabletEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#tabletEvent

        **[virtual protected] void QWindow::tabletEvent(QTabletEvent * ev )**

        Override this to handle tablet press, move, and release events ( **ev**
        ).

        Proximity enter and leave events are not sent to windows, they are
        delivered to the application instance.
        """
        ...

    def touchEvent(self, a0: QTouchEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#touchEvent

        **[virtual protected] void QWindow::touchEvent(QTouchEvent * ev )**

        Override this to handle touch events ( **ev** ).
        """
        ...

    def wheelEvent(self, a0: QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#wheelEvent

        **[virtual protected] void QWindow::wheelEvent(QWheelEvent * ev )**

        Override this to handle mouse wheel or other wheel events ( **ev** ).
        """
        ...

    def mouseMoveEvent(self, a0: QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#mouseMoveEvent

        **[virtual protected] void QWindow::mouseMoveEvent(QMouseEvent * ev )**

        Override this to handle mouse move events ( **ev** ).
        """
        ...

    def mouseDoubleClickEvent(self, a0: QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#mouseDoubleClickEvent

        **[virtual protected] void QWindow::mouseDoubleClickEvent(QMouseEvent *
        ev )**

        Override this to handle mouse double click events ( **ev** ).

        **See also** **mousePressEvent** () and
        **QStyleHints::mouseDoubleClickInterval** ().
        """
        ...

    def mouseReleaseEvent(self, a0: QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#mouseReleaseEvent

        **[virtual protected] void QWindow::mouseReleaseEvent(QMouseEvent * ev
        )**

        Override this to handle mouse release events ( **ev** ).

        **See also** **mousePressEvent** ().
        """
        ...

    def mousePressEvent(self, a0: QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#mousePressEvent

        **[virtual protected] void QWindow::mousePressEvent(QMouseEvent * ev )**

        Override this to handle mouse press events ( **ev** ).

        **See also** **mouseReleaseEvent** ().
        """
        ...

    def keyReleaseEvent(self, a0: QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#keyReleaseEvent

        **[virtual protected] void QWindow::keyReleaseEvent(QKeyEvent * ev )**

        Override this to handle key release events ( **ev** ).

        **See also** **keyPressEvent** ().
        """
        ...

    def keyPressEvent(self, a0: QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#keyPressEvent

        **[virtual protected] void QWindow::keyPressEvent(QKeyEvent * ev )**

        Override this to handle key press events ( **ev** ).

        **See also** **keyReleaseEvent** ().
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#event

        **[override virtual protected] bool QWindow::event(QEvent * ev )**

        Reimplements: **QObject::event** (QEvent *e).

        Override this to handle any event ( **ev** ) sent to the window. Return
        `true` if the event was recognized and processed.

        Remember to call the base class version if you wish for mouse events,
        key events, resize events, etc to be dispatched as usual.
        """
        ...

    def hideEvent(self, a0: QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#hideEvent

        **[virtual protected] void QWindow::hideEvent(QHideEvent * ev )**

        Override this to handle hide events ( **ev** ).

        The function is called when the window has requested being hidden in the
        windowing system.
        """
        ...

    def showEvent(self, a0: QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#showEvent

        **[virtual protected] void QWindow::showEvent(QShowEvent * ev )**

        Override this to handle show events ( **ev** ).

        The function is called when the window has requested becoming visible.

        If the window is successfully shown by the windowing system, this will
        be followed by a resize and an expose event.
        """
        ...

    def focusOutEvent(self, a0: QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#focusOutEvent

        **[virtual protected] void QWindow::focusOutEvent(QFocusEvent * ev )**

        Override this to handle focus out events ( **ev** ).

        Focus out events are sent when the window loses keyboard focus.

        **See also** **focusInEvent** ().
        """
        ...

    def focusInEvent(self, a0: QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#focusInEvent

        **[virtual protected] void QWindow::focusInEvent(QFocusEvent * ev )**

        Override this to handle focus in events ( **ev** ).

        Focus in events are sent when the window receives keyboard focus.

        **See also** **focusOutEvent** ().
        """
        ...

    def moveEvent(self, a0: QMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#moveEvent

        **[virtual protected] void QWindow::moveEvent(QMoveEvent * ev )**

        Override this to handle window move events ( **ev** ).
        """
        ...

    def resizeEvent(self, a0: QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#resizeEvent

        **[virtual protected] void QWindow::resizeEvent(QResizeEvent * ev )**

        Override this to handle resize events ( **ev** ).

        The resize event is called whenever the window is resized in the
        windowing system, either directly through the windowing system
        acknowledging a **setGeometry** () or **resize** () request, or
        indirectly through the user resizing the window manually.
        """
        ...

    def exposeEvent(self, a0: QExposeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#exposeEvent

        **[virtual protected] void QWindow::exposeEvent(QExposeEvent * ev )**

        The expose event ( **ev** ) is sent by the window system when a window
        moves between the un-exposed and exposed states.

        An exposed window is potentially visible to the user. If the window is
        moved off screen, is made totally obscured by another window, is
        minimized, or similar, this function might be called and the value of
        **isExposed** () might change to false. You may use this event to limit
        expensive operations such as animations to only run when the window is
        exposed.

        This event should not be used to paint. To handle painting implement
        **paintEvent** () instead.

        A resize event will always be sent before the expose event the first
        time a window is shown.

        **See also** **paintEvent** () and **isExposed** ().
        """
        ...

    def requestUpdate(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#requestUpdate

        **[slot, since 5.5] void QWindow::requestUpdate()**

        Schedules a **QEvent::UpdateRequest**  event to be delivered to this
        window.

        The event is delivered in sync with the display vsync on platforms where
        this is possible. Otherwise, the event is delivered after a delay of 5
        ms. The additional time is there to give the event loop a bit of idle
        time to gather system events, and can be overridden using the
        QT_QPA_UPDATE_IDLE_TIME environment variable.

        When driving animations, this function should be called once after
        drawing has completed. Calling this function multiple times will result
        in a single event being delivered to the window.

        Subclasses of **QWindow**  should reimplement **event** (), intercept
        the event and call the application's rendering code, then call the base
        class implementation.

        **Note:** The subclass' reimplementation of **event** () must invoke the
        base class implementation, unless it is absolutely sure that the event
        does not need to be handled by the base class. For example, the default
        implementation of this function relies on **QEvent::Timer**  events.
        Filtering them away would therefore break the delivery of the update
        events.

        This function was introduced in Qt 5.5.
        """
        ...

    def alert(self, msec: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#alert

        **[slot, since 5.1] void QWindow::alert(int msec )**

        Causes an alert to be shown for **msec** milliseconds. If **msec** is
        `0` (the default), then the alert is shown indefinitely until the window
        becomes active again. This function has no effect on an active window.

        In alert state, the window indicates that it demands attention, for
        example by flashing or bouncing the taskbar entry.

        This function was introduced in Qt 5.1.
        """
        ...

    def setMaximumHeight(self, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#maximumHeight-prop

        **maximumHeight : int**

        This property holds the maximum height of the window's geometry

        **Access functions:**

        int **maximumHeight** () const
        void **setMaximumHeight** (int **h** )

        **Notifier signal:**

        void **maximumHeightChanged** (int **arg** )
        """
        ...

    def setMaximumWidth(self, w: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#maximumWidth-prop

        **maximumWidth : int**

        This property holds the maximum width of the window's geometry

        **Access functions:**

        int **maximumWidth** () const
        void **setMaximumWidth** (int **w** )

        **Notifier signal:**

        void **maximumWidthChanged** (int **arg** )
        """
        ...

    def setMinimumHeight(self, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#minimumHeight-prop

        **minimumHeight : int**

        This property holds the minimum height of the window's geometry

        **Access functions:**

        int **minimumHeight** () const
        void **setMinimumHeight** (int **h** )

        **Notifier signal:**

        void **minimumHeightChanged** (int **arg** )
        """
        ...

    def setMinimumWidth(self, w: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#minimumWidth-prop

        **minimumWidth : int**

        This property holds the minimum width of the window's geometry

        **Access functions:**

        int **minimumWidth** () const
        void **setMinimumWidth** (int **w** )

        **Notifier signal:**

        void **minimumWidthChanged** (int **arg** )
        """
        ...

    def setHeight(self, arg: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#height-prop

        **height : int**

        This property holds the height of the window's geometry

        **Access functions:**

        int **height** () const
        void **setHeight** (int **arg** )

        **Notifier signal:**

        void **heightChanged** (int **arg** )
        """
        ...

    def setWidth(self, arg: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#width-prop

        **width : int**

        This property holds the width of the window's geometry

        **Access functions:**

        int **width** () const
        void **setWidth** (int **arg** )

        **Notifier signal:**

        void **widthChanged** (int **arg** )
        """
        ...

    def setY(self, arg: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#y-prop

        **y : int**

        This property holds the y position of the window's geometry

        **Access functions:**

        int **y** () const
        void **setY** (int **arg** )

        **Notifier signal:**

        void **yChanged** (int **arg** )

        **Member Function Documentation**
        """
        ...

    def setX(self, arg: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#x-prop

        **x : int**

        This property holds the x position of the window's geometry

        **Access functions:**

        int **x** () const
        void **setX** (int **arg** )

        **Notifier signal:**

        void **xChanged** (int **arg** )
        """
        ...

    def setTitle(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#title-prop

        **title : QString**

        This property holds the window's title in the windowing system

        The window title might appear in the title area of the window
        decorations, depending on the windowing system and the window flags. It
        might also be used by the windowing system to identify the window in
        other contexts, such as in the task switcher.

        **Access functions:**

        QString **title** () const
        void **setTitle** (const QString &)

        **Notifier signal:**

        void **windowTitleChanged** (const QString & **title** )

        **See also** **flags** ().
        """
        ...

    def lower(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#lower

        **[slot] void QWindow::lower()**

        Lower the window in the windowing system.

        Requests that the window be lowered to appear below other windows.
        """
        ...

    def raise_(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#raise

        **[slot] void QWindow::raise()**

        Raise the window in the windowing system.

        Requests that the window be raised to appear above other windows.
        """
        ...

    def close(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#close

        **[slot] bool QWindow::close()**

        Close the window.

        This closes the window, effectively calling **destroy** (), and
        potentially quitting the application. Returns `true` on success, false
        if it has a parent window (in which case the top level window should be
        closed instead).

        **See also** **destroy** (), **QGuiApplication::quitOnLastWindowClosed**
        (), and **closeEvent** ().
        """
        ...

    def showNormal(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#showNormal

        **[slot] void QWindow::showNormal()**

        Shows the window as normal, i.e. neither maximized, minimized, nor
        fullscreen.

        Equivalent to calling **setWindowStates** (**Qt::WindowNoState** ) and
        then **setVisible** (true).

        **See also** **setWindowStates** () and **setVisible** ().
        """
        ...

    def showFullScreen(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#showFullScreen

        **[slot] void QWindow::showFullScreen()**

        Shows the window as fullscreen.

        Equivalent to calling **setWindowStates** (**Qt::WindowFullScreen** )
        and then **setVisible** (true).

        See the **QWidget::showFullScreen** () documentation for platform-
        specific considerations and limitations.

        **See also** **setWindowStates** () and **setVisible** ().
        """
        ...

    def showMaximized(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#showMaximized

        **[slot] void QWindow::showMaximized()**

        Shows the window as maximized.

        Equivalent to calling **setWindowStates** (**Qt::WindowMaximized** ) and
        then **setVisible** (true).

        **See also** **setWindowStates** () and **setVisible** ().
        """
        ...

    def showMinimized(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#showMinimized

        **[slot] void QWindow::showMinimized()**

        Shows the window as minimized.

        Equivalent to calling **setWindowStates** (**Qt::WindowMinimized** ) and
        then **setVisible** (true).

        **See also** **setWindowStates** () and **setVisible** ().
        """
        ...

    def hide(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#hide

        **[slot] void QWindow::hide()**

        Hides the window.

        Equivalent to calling **setVisible** (false).

        **See also** **show** () and **setVisible** ().
        """
        ...

    def show(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#show

        **[slot] void QWindow::show()**

        Shows the window.

        This is equivalent to calling **showFullScreen** (), **showMaximized**
        (), or **showNormal** (), depending on the platform's default behavior
        for the window type and flags.

        **See also** **showFullScreen** (), **showMaximized** (), **showNormal**
        (), **hide** (), **QStyleHints::showIsFullScreen** (), and **flags** ().
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#visible-prop

        **visible : bool**

        This property holds whether the window is visible or not

        This property controls the visibility of the window in the windowing
        system.

        By default, the window is not visible, you must call setVisible(true),
        or **show** () or similar to make it visible.

        **Note:** Hiding a window does not remove the window from the windowing
        system, it only hides it. On windowing systems that give full screen
        applications a dedicated desktop (such as macOS), hiding a full screen
        window will not remove that desktop, but leave it blank. Another window
        from the same application might be shown full screen, and will fill that
        desktop. Use **QWindow::close**  to completely remove a window from the
        windowing system.

        **Access functions:**

        bool **isVisible** () const
        void **setVisible** (bool **visible** )

        **Notifier signal:**

        void **visibleChanged** (bool **arg** )

        **See also** **show** ().
        """
        ...

    def unsetCursor(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#unsetCursor

        **void QWindow::unsetCursor()**

        Restores the default arrow cursor for this window.
        """
        ...

    def setCursor(self, a0: typing.Union[QCursor, QtCore.Qt.CursorShape]) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setCursor

        **void QWindow::setCursor(const QCursor & cursor )**

        set the cursor shape for this window

        The mouse **cursor** will assume this shape when it is over this window,
        unless an override cursor is set. See the **list of predefined cursor
        objects**  for a range of useful shapes.

        If no cursor has been set, or after a call to **unsetCursor** (), the
        parent window's cursor is used.

        By default, the cursor has the **Qt::ArrowCursor**  shape.

        Some underlying window implementations will reset the cursor if it
        leaves a window even if the mouse is grabbed. If you want to have a
        cursor set for all windows, even when outside the window, consider
        **QGuiApplication::setOverrideCursor** ().

        **See also** **cursor** () and **QGuiApplication::setOverrideCursor**
        ().
        """
        ...

    def cursor(self) -> QCursor:
        """
        https://doc.qt.io/qt-6/qwindow.html#cursor

        **QCursor QWindow::cursor() const**

        the cursor shape for this window

        **See also** **setCursor** () and **unsetCursor** ().
        """
        ...

    @typing.overload
    def mapFromGlobal(self, pos: QtCore.QPoint) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qwindow.html#mapFromGlobal

        **[since 6.0] QPointF QWindow::mapFromGlobal(const QPointF & pos )
        const**

        Translates the global screen coordinate **pos** to window coordinates.

        This function was introduced in Qt 6.0.

        **See also** **mapToGlobal** ().
        """
        ...

    @typing.overload
    def mapFromGlobal(self, pos: QtCore.QPointF) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qwindow.html#mapFromGlobal-1

        **QPoint QWindow::mapFromGlobal(const QPoint & pos ) const**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def mapToGlobal(self, pos: QtCore.QPoint) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qwindow.html#mapToGlobal

        **[since 6.0] QPointF QWindow::mapToGlobal(const QPointF & pos ) const**

        Translates the window coordinate **pos** to global screen coordinates.
        For example, `mapToGlobal(QPointF(0,0))` would give the global
        coordinates of the top-left pixel of the window.

        This function was introduced in Qt 6.0.

        **See also** **mapFromGlobal** ().
        """
        ...

    @typing.overload
    def mapToGlobal(self, pos: QtCore.QPointF) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qwindow.html#mapToGlobal-1

        **QPoint QWindow::mapToGlobal(const QPoint & pos ) const**

        This is an overloaded function.
        """
        ...

    def focusObject(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qwindow.html#focusObject

        **[virtual] QObject *QWindow::focusObject() const**

        Returns the **QObject**  that will be the final receiver of events tied
        focus, such as key events.
        """
        ...

    def setScreen(self, screen: "QScreen") -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setScreen

        **void QWindow::setScreen(QScreen * newScreen )**

        Sets the screen on which the window should be shown.

        If the window has been created, it will be recreated on the
        **newScreen**.

        **Note:** If the screen is part of a virtual desktop of multiple
        screens, the window will not move automatically to **newScreen**. To
        place the window relative to the screen, use the screen's topLeft()
        position.

        This function only works for top level windows.

        **See also** **screen** () and **QScreen::virtualSiblings** ().
        """
        ...

    def screen(self) -> "QScreen":
        """
        https://doc.qt.io/qt-6/qwindow.html#screen

        **QScreen *QWindow::screen() const**

        Returns the screen on which the window is shown, or null if there is
        none.

        For child windows, this returns the screen of the corresponding top
        level window.

        **See also** **setScreen** () and **QScreen::virtualSiblings** ().
        """
        ...

    def setMouseGrabEnabled(self, grab: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#setMouseGrabEnabled

        **bool QWindow::setMouseGrabEnabled(bool grab )**

        Sets whether mouse grab should be enabled or not ( **grab** ).

        If the return value is true, the window receives all mouse events until
        setMouseGrabEnabled(false) is called; other windows get no mouse events
        at all. Keyboard events are not affected. Use **setKeyboardGrabEnabled**
        () if you want to grab that.

        **See also** **setKeyboardGrabEnabled** ().
        """
        ...

    def setKeyboardGrabEnabled(self, grab: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#setKeyboardGrabEnabled

        **bool QWindow::setKeyboardGrabEnabled(bool grab )**

        Sets whether keyboard grab should be enabled or not ( **grab** ).

        If the return value is true, the window receives all key events until
        setKeyboardGrabEnabled(false) is called; other windows get no key events
        at all. Mouse events are not affected. Use **setMouseGrabEnabled** () if
        you want to grab that.

        **See also** **setMouseGrabEnabled** ().
        """
        ...

    def destroy(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#destroy

        **void QWindow::destroy()**

        Releases the native platform resources associated with this window.

        **See also** **create** ().
        """
        ...

    def icon(self) -> QIcon:
        """
        https://doc.qt.io/qt-6/qwindow.html#icon

        **QIcon QWindow::icon() const**

        Returns the window's icon in the windowing system

        **See also** **setIcon** ().
        """
        ...

    def setIcon(self, icon: QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setIcon

        **void QWindow::setIcon(const QIcon & icon )**

        Sets the window's **icon** in the windowing system

        The window icon might be used by the windowing system for example to
        decorate the window, and/or in the task switcher.

        **Note:** On macOS, the window title bar icon is meant for windows
        representing documents, and will only show up if a file path is also
        set.

        **See also** **icon** () and **setFilePath** ().
        """
        ...

    def filePath(self) -> str:
        """
        https://doc.qt.io/qt-6/qwindow.html#filePath

        **QString QWindow::filePath() const**

        the file name this window is representing.

        **See also** **setFilePath** ().
        """
        ...

    def setFilePath(self, filePath: str) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setFilePath

        **void QWindow::setFilePath(const QString & filePath )**

        set the file name this window is representing.

        The windowing system might use **filePath** to display the path of the
        document this window is representing in the tile bar.

        **See also** **filePath** ().
        """
        ...

    @typing.overload
    def resize(self, newSize: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#resize

        **void QWindow::resize(const QSize & newSize )**

        set the size of the window, excluding any window frame, to **newSize**

        **See also** **size** () and **geometry** ().
        """
        ...

    @typing.overload
    def resize(self, w: int, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#resize-1

        **void QWindow::resize(int w , int h )**

        set the size of the window, excluding any window frame, to a **QSize**
        constructed from width **w** and height **h**

        For interactively resizing windows, see **startSystemResize** ().

        **See also** **size** () and **geometry** ().
        """
        ...

    @typing.overload
    def setPosition(self, pt: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setPosition

        **void QWindow::setPosition(const QPoint & pt )**

        set the position of the window on the desktop to **pt**

        The position is in relation to the virtualGeometry() of its screen.

        For interactively moving windows, see **startSystemMove** (). For
        interactively resizing windows, see **startSystemResize** ().

        **See also** **position** () and **startSystemMove** ().
        """
        ...

    @typing.overload
    def setPosition(self, posx: int, posy: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setPosition-1

        **void QWindow::setPosition(int posx , int posy )**

        set the position of the window on the desktop to **posx** , **posy**

        The position is in relation to the virtualGeometry() of its screen.

        **See also** **position** ().
        """
        ...

    def position(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qwindow.html#position

        **QPoint QWindow::position() const**

        Returns the position of the window on the desktop excluding any window
        frame

        **See also** **setPosition** ().
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwindow.html#size

        **[override virtual] QSize QWindow::size() const**

        Reimplements: **QSurface::size() const** .

        Returns the size of the window excluding any window frame

        **See also** **resize** ().
        """
        ...

    def y(self) -> int:
        """
        https://doc.qt.io/qt-6/qwindow.html#y-prop

        **y : int**

        This property holds the y position of the window's geometry

        **Access functions:**

        int **y** () const
        void **setY** (int **arg** )

        **Notifier signal:**

        void **yChanged** (int **arg** )

        **Member Function Documentation**
        """
        ...

    def x(self) -> int:
        """
        https://doc.qt.io/qt-6/qwindow.html#x-prop

        **x : int**

        This property holds the x position of the window's geometry

        **Access functions:**

        int **x** () const
        void **setX** (int **arg** )

        **Notifier signal:**

        void **xChanged** (int **arg** )
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qwindow.html#height-prop

        **height : int**

        This property holds the height of the window's geometry

        **Access functions:**

        int **height** () const
        void **setHeight** (int **arg** )

        **Notifier signal:**

        void **heightChanged** (int **arg** )
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qwindow.html#width-prop

        **width : int**

        This property holds the width of the window's geometry

        **Access functions:**

        int **width** () const
        void **setWidth** (int **arg** )

        **Notifier signal:**

        void **widthChanged** (int **arg** )
        """
        ...

    def setFramePosition(self, point: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setFramePosition

        **void QWindow::setFramePosition(const QPoint & point )**

        Sets the upper left position of the window ( **point** ) including its
        window frame.

        The position is in relation to the virtualGeometry() of its screen.

        **See also** **framePosition** (), **setGeometry** (), and
        **frameGeometry** ().
        """
        ...

    def framePosition(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qwindow.html#framePosition

        **QPoint QWindow::framePosition() const**

        Returns the top left position of the window, including its window frame.

        This returns the same value as **frameGeometry** ().topLeft().

        **See also** **setFramePosition** (), **geometry** (), and
        **frameGeometry** ().
        """
        ...

    def frameGeometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qwindow.html#frameGeometry

        **QRect QWindow::frameGeometry() const**

        Returns the geometry of the window, including its window frame.

        The geometry is in relation to the virtualGeometry() of its screen.

        **See also** **geometry** () and **frameMargins** ().
        """
        ...

    def frameMargins(self) -> QtCore.QMargins:
        """
        https://doc.qt.io/qt-6/qwindow.html#frameMargins

        **QMargins QWindow::frameMargins() const**

        Returns the window frame margins surrounding the window.

        **See also** **geometry** () and **frameGeometry** ().
        """
        ...

    def geometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qwindow.html#geometry

        **QRect QWindow::geometry() const**

        Returns the geometry of the window, excluding its window frame.

        The geometry is in relation to the virtualGeometry() of its screen.

        **See also** **setGeometry** (), **frameMargins** (), and
        **frameGeometry** ().
        """
        ...

    @typing.overload
    def setGeometry(self, posx: int, posy: int, w: int, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setGeometry

        **[slot] void QWindow::setGeometry(int posx , int posy , int w , int h
        )**

        Sets the geometry of the window, excluding its window frame, to a
        rectangle constructed from **posx** , **posy** , **w** and **h**.

        The geometry is in relation to the virtualGeometry() of its screen.

        **See also** **geometry** ().
        """
        ...

    @typing.overload
    def setGeometry(self, rect: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setGeometry-1

        **[slot] void QWindow::setGeometry(const QRect & rect )**

        Sets the geometry of the window, excluding its window frame, to
        **rect**.

        The geometry is in relation to the virtualGeometry() of its screen.

        **See also** **geometry** ().
        """
        ...

    def setSizeIncrement(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setSizeIncrement

        **void QWindow::setSizeIncrement(const QSize & size )**

        Sets the size increment ( **size** ) of the window.

        When the user resizes the window, the size will move in steps of
        **sizeIncrement** ().**width** () pixels horizontally and
        **sizeIncrement** ().**height** () pixels vertically, with **baseSize**
        () as the basis.

        By default, this property contains a size with zero width and height.

        The windowing system might not support size increments.

        **See also** **sizeIncrement** (), **setBaseSize** (),
        **setMinimumSize** (), and **setMaximumSize** ().
        """
        ...

    def setBaseSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setBaseSize

        **void QWindow::setBaseSize(const QSize & size )**

        Sets the base **size** of the window.

        The base size is used to calculate a proper window size if the window
        defines **sizeIncrement** ().

        **See also** **setMinimumSize** (), **setMaximumSize** (),
        **setSizeIncrement** (), and **baseSize** ().
        """
        ...

    def setMaximumSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setMaximumSize

        **void QWindow::setMaximumSize(const QSize & size )**

        Sets the maximum size of the window.

        This is a hint to the window manager to prevent resizing above the
        specified **size**.

        **See also** **setMinimumSize** () and **maximumSize** ().
        """
        ...

    def setMinimumSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setMinimumSize

        **void QWindow::setMinimumSize(const QSize & size )**

        Sets the minimum size of the window.

        This is a hint to the window manager to prevent resizing below the
        specified **size**.

        **See also** **setMaximumSize** () and **minimumSize** ().
        """
        ...

    def sizeIncrement(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwindow.html#sizeIncrement

        **QSize QWindow::sizeIncrement() const**

        Returns the size increment of the window.

        **See also** **setSizeIncrement** ().
        """
        ...

    def baseSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwindow.html#baseSize

        **QSize QWindow::baseSize() const**

        Returns the base size of the window.

        **See also** **setBaseSize** ().
        """
        ...

    def maximumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwindow.html#maximumSize

        **QSize QWindow::maximumSize() const**

        Returns the maximum size of the window.

        **See also** **setMaximumSize** ().
        """
        ...

    def minimumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwindow.html#minimumSize

        **QSize QWindow::minimumSize() const**

        Returns the minimum size of the window.

        **See also** **setMinimumSize** ().
        """
        ...

    def maximumHeight(self) -> int:
        """
        https://doc.qt.io/qt-6/qwindow.html#maximumHeight-prop

        **maximumHeight : int**

        This property holds the maximum height of the window's geometry

        **Access functions:**

        int **maximumHeight** () const
        void **setMaximumHeight** (int **h** )

        **Notifier signal:**

        void **maximumHeightChanged** (int **arg** )
        """
        ...

    def maximumWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qwindow.html#maximumWidth-prop

        **maximumWidth : int**

        This property holds the maximum width of the window's geometry

        **Access functions:**

        int **maximumWidth** () const
        void **setMaximumWidth** (int **w** )

        **Notifier signal:**

        void **maximumWidthChanged** (int **arg** )
        """
        ...

    def minimumHeight(self) -> int:
        """
        https://doc.qt.io/qt-6/qwindow.html#minimumHeight-prop

        **minimumHeight : int**

        This property holds the minimum height of the window's geometry

        **Access functions:**

        int **minimumHeight** () const
        void **setMinimumHeight** (int **h** )

        **Notifier signal:**

        void **minimumHeightChanged** (int **arg** )
        """
        ...

    def minimumWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qwindow.html#minimumWidth-prop

        **minimumWidth : int**

        This property holds the minimum width of the window's geometry

        **Access functions:**

        int **minimumWidth** () const
        void **setMinimumWidth** (int **w** )

        **Notifier signal:**

        void **minimumWidthChanged** (int **arg** )
        """
        ...

    def isExposed(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#isExposed

        **bool QWindow::isExposed() const**

        Returns if this window is exposed in the windowing system.

        When the window is not exposed, it is shown by the application but it is
        still not showing in the windowing system, so the application should
        minimize animations and other graphical activities.

        An **exposeEvent** () is sent every time this value changes.

        **See also** **exposeEvent** ().
        """
        ...

    def isAncestorOf(
        self, child: "QWindow", mode: "QWindow.AncestorMode" = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#isAncestorOf

        **bool QWindow::isAncestorOf(const QWindow * child ,
        QWindow::AncestorMode mode = IncludeTransients) const**

        Returns `true` if the window is an ancestor of the given **child**. If
        **mode** is **IncludeTransients** , then transient parents are also
        considered ancestors.
        """
        ...

    def transientParent(self) -> "QWindow":
        """
        https://doc.qt.io/qt-6/qwindow.html#transientParent-prop

        **[since 5.13] transientParent : QWindow***

        This property holds the window for which this window is a transient pop-
        up

        This is a hint to the window manager that this window is a dialog or
        pop-up on behalf of the transient parent.

        In order to cause the window to be centered above its transient
        **parent** by default, depending on the window manager, it may also be
        necessary to call **setFlags** () with a suitable **Qt::WindowType**
        (such as `Qt::Dialog`).

        This property was introduced in Qt 5.13.

        **Access functions:**

        QWindow * **transientParent** () const
        void **setTransientParent**
        (QWindow * **parent** )

        **Notifier signal:**

        void **transientParentChanged** (QWindow * **transientParent** )

        **See also** **parent** ().
        """
        ...

    def setTransientParent(self, parent: "QWindow") -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#transientParent-prop

        **[since 5.13] transientParent : QWindow***

        This property holds the window for which this window is a transient pop-
        up

        This is a hint to the window manager that this window is a dialog or
        pop-up on behalf of the transient parent.

        In order to cause the window to be centered above its transient
        **parent** by default, depending on the window manager, it may also be
        necessary to call **setFlags** () with a suitable **Qt::WindowType**
        (such as `Qt::Dialog`).

        This property was introduced in Qt 5.13.

        **Access functions:**

        QWindow * **transientParent** () const
        void **setTransientParent**
        (QWindow * **parent** )

        **Notifier signal:**

        void **transientParentChanged** (QWindow * **transientParent** )

        **See also** **parent** ().
        """
        ...

    def setWindowState(self, state: QtCore.Qt.WindowState) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setWindowState

        **void QWindow::setWindowState(Qt::WindowState state )**

        set the screen-occupation state of the window

        The window **state** represents whether the window appears in the
        windowing system as maximized, minimized, fullscreen, or normal.

        The enum value **Qt::WindowActive**  is not an accepted parameter.

        **See also** **windowState** (), **showNormal** (), **showFullScreen**
        (), **showMinimized** (), **showMaximized** (), and **setWindowStates**
        ().
        """
        ...

    def windowState(self) -> QtCore.Qt.WindowState:
        """
        https://doc.qt.io/qt-6/qwindow.html#windowState

        **Qt::WindowState QWindow::windowState() const**

        the screen-occupation state of the window

        **See also** **setWindowState** () and **windowStates** ().
        """
        ...

    def devicePixelRatio(self) -> float:
        """
        https://doc.qt.io/qt-6/qwindow.html#devicePixelRatio

        **qreal QWindow::devicePixelRatio() const**

        Returns the ratio between physical pixels and device-independent pixels
        for the window. This value is dependent on the screen the window is on,
        and may change when the window is moved.

        Common values are 1.0 on normal displays and 2.0 on Apple "retina"
        displays.

        **Note:** For windows not backed by a platform window, meaning that
        **create** () was not called, the function will fall back to the
        associated **QScreen** 's device pixel ratio.

        **See also** **QScreen::devicePixelRatio** ().
        """
        ...

    def contentOrientation(self) -> QtCore.Qt.ScreenOrientation:
        """
        https://doc.qt.io/qt-6/qwindow.html#contentOrientation-prop

        **contentOrientation : Qt::ScreenOrientation**

        This property holds the orientation of the window's contents

        This is a hint to the window manager in case it needs to display
        additional content like popups, dialogs, status bars, or similar in
        relation to the window.

        The recommended orientation is **QScreen::orientation** () but an
        application doesn't have to support all possible orientations, and thus
        can opt to ignore the current screen orientation.

        The difference between the window and the content orientation determines
        how much to rotate the content by. **QScreen::angleBetween** (),
        **QScreen::transformBetween** (), and **QScreen::mapBetween** () can be
        used to compute the necessary transform.

        The default value is **Qt::PrimaryOrientation**

        **Access functions:**

        Qt::ScreenOrientation **contentOrientation** () const
        void
        **reportContentOrientationChange** (Qt::ScreenOrientation
        **orientation** )

        **Notifier signal:**

        void **contentOrientationChanged** (Qt::ScreenOrientation
        **orientation** )
        """
        ...

    def reportContentOrientationChange(
        self, orientation: QtCore.Qt.ScreenOrientation
    ) -> None:
        ...

    def isActive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#isActive

        **bool QWindow::isActive() const**

        Returns `true` if the window is active.

        This is the case for the window that has input focus as well as windows
        that are in the same parent / transient parent chain as the focus
        window.

        Typically active windows should appear active from a style perspective.

        To get the window that currently has focus, use
        **QGuiApplication::focusWindow** ().

        **Note:** Getter function for property **active** .
        """
        ...

    def requestActivate(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#requestActivate

        **[slot] void QWindow::requestActivate()**

        Requests the window to be activated, i.e. receive keyboard focus.

        **See also** **isActive** () and **QGuiApplication::focusWindow** ().
        """
        ...

    def setOpacity(self, level: float) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#opacity-prop

        **[since 5.1] opacity : qreal**

        This property holds the opacity of the window in the windowing system.

        If the windowing system supports window opacity, this can be used to
        fade the window in and out, or to make it semitransparent.

        A value of 1.0 or above is treated as fully opaque, whereas a value of
        0.0 or below is treated as fully transparent. Values inbetween represent
        varying levels of translucency between the two extremes.

        The default value is 1.0.

        This property was introduced in Qt 5.1.

        **Access functions:**

        qreal **opacity** () const
        void **setOpacity** (qreal **level** )

        **Notifier signal:**

        void **opacityChanged** (qreal **opacity** )
        """
        ...

    def title(self) -> str:
        """
        https://doc.qt.io/qt-6/qwindow.html#title-prop

        **title : QString**

        This property holds the window's title in the windowing system

        The window title might appear in the title area of the window
        decorations, depending on the windowing system and the window flags. It
        might also be used by the windowing system to identify the window in
        other contexts, such as in the task switcher.

        **Access functions:**

        QString **title** () const
        void **setTitle** (const QString &)

        **Notifier signal:**

        void **windowTitleChanged** (const QString & **title** )

        **See also** **flags** ().
        """
        ...

    def type(self) -> QtCore.Qt.WindowType:
        """
        https://doc.qt.io/qt-6/qwindow.html#type

        **Qt::WindowType QWindow::type() const**

        Returns the type of the window.

        This returns the part of the window flags that represents whether the
        window is a dialog, tooltip, popup, regular window, etc.

        **See also** **flags** () and **setFlags** ().
        """
        ...

    def flags(self) -> QtCore.Qt.WindowType:
        """
        https://doc.qt.io/qt-6/qwindow.html#flags-prop

        **flags : Qt::WindowFlags**

        This property holds the window flags of the window

        The window flags control the window's appearance in the windowing
        system, whether it's a dialog, popup, or a regular window, and whether
        it should have a title bar, etc.

        The actual window flags might differ from the flags set with setFlags()
        if the requested flags could not be fulfilled.

        **Access functions:**

        Qt::WindowFlags **flags** () const
        void **setFlags** (Qt::WindowFlags
        **flags** )

        **See also** **setFlag** ().
        """
        ...

    def setFlags(self, flags: QtCore.Qt.WindowType) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#flags-prop

        **flags : Qt::WindowFlags**

        This property holds the window flags of the window

        The window flags control the window's appearance in the windowing
        system, whether it's a dialog, popup, or a regular window, and whether
        it should have a title bar, etc.

        The actual window flags might differ from the flags set with setFlags()
        if the requested flags could not be fulfilled.

        **Access functions:**

        Qt::WindowFlags **flags** () const
        void **setFlags** (Qt::WindowFlags
        **flags** )

        **See also** **setFlag** ().
        """
        ...

    def requestedFormat(self) -> "QSurfaceFormat":
        """
        https://doc.qt.io/qt-6/qwindow.html#requestedFormat

        **QSurfaceFormat QWindow::requestedFormat() const**

        Returns the requested surface format of this window.

        If the requested format was not supported by the platform
        implementation, the requestedFormat will differ from the actual window
        format.

        This is the value set with **setFormat** ().

        **See also** **setFormat** () and **format** ().
        """
        ...

    def format(self) -> "QSurfaceFormat":
        """
        https://doc.qt.io/qt-6/qwindow.html#format

        **[override virtual] QSurfaceFormat QWindow::format() const**

        Reimplements: **QSurface::format() const** .

        Returns the actual format of this window.

        After the window has been created, this function will return the actual
        surface format of the window. It might differ from the requested format
        if the requested format could not be fulfilled by the platform. It might
        also be a superset, for example certain buffer sizes may be larger than
        requested.

        **Note:** Depending on the platform, certain values in this surface
        format may still contain the requested values, that is, the values that
        have been passed to **setFormat** (). Typical examples are the OpenGL
        version, profile and options. These may not get updated during
        **create** () since these are context specific and a single window may
        be used together with multiple contexts over its lifetime. Use the
        **QOpenGLContext** 's format() instead to query such values.

        **See also** **setFormat** (), **create** (), **requestedFormat** (),
        and **QOpenGLContext::format** ().
        """
        ...

    def setFormat(self, format: "QSurfaceFormat") -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setFormat

        **void QWindow::setFormat(const QSurfaceFormat & format )**

        Sets the window's surface **format**.

        The format determines properties such as color depth, alpha, depth and
        stencil buffer size, etc. For example, to give a window a transparent
        background (provided that the window system supports compositing, and
        provided that other content in the window does not make it opaque
        again):

        **QSurfaceFormat**  format;
            format.setAlphaBufferSize(8);
        window.setFormat(format);

        The surface format will be resolved in the **create** () function.
        Calling this function after **create** () has been called will not re-
        resolve the surface format of the native surface.

        When the format is not explicitly set via this function, the format
        returned by **QSurfaceFormat::defaultFormat** () will be used. This
        means that when having multiple windows, individual calls to this
        function can be replaced by one single call to
        **QSurfaceFormat::setDefaultFormat** () before creating the first
        window.

        **See also** **format** (), **create** (), **destroy** (), and
        **QSurfaceFormat::setDefaultFormat** ().
        """
        ...

    def setModality(self, modality: QtCore.Qt.WindowModality) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#modality-prop

        **modality : Qt::WindowModality**

        This property holds the modality of the window

        A modal window prevents other windows from receiving input events. Qt
        supports two types of modality: **Qt::WindowModal**  and
        **Qt::ApplicationModal** .

        By default, this property is **Qt::NonModal**

        **Access functions:**

        Qt::WindowModality **modality** () const
        void **setModality**
        (Qt::WindowModality **modality** )

        **Notifier signal:**

        void ****modalityChanged** ** (Qt::WindowModality **modality** )

        **See also** **Qt::WindowModality** .
        """
        ...

    def modality(self) -> QtCore.Qt.WindowModality:
        """
        https://doc.qt.io/qt-6/qwindow.html#modality-prop

        **modality : Qt::WindowModality**

        This property holds the modality of the window

        A modal window prevents other windows from receiving input events. Qt
        supports two types of modality: **Qt::WindowModal**  and
        **Qt::ApplicationModal** .

        By default, this property is **Qt::NonModal**

        **Access functions:**

        Qt::WindowModality **modality** () const
        void **setModality**
        (Qt::WindowModality **modality** )

        **Notifier signal:**

        void ****modalityChanged** ** (Qt::WindowModality **modality** )

        **See also** **Qt::WindowModality** .
        """
        ...

    def isModal(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#isModal

        **bool QWindow::isModal() const**

        Returns whether the window is modal.

        A modal window prevents other windows from getting any input.

        **See also** **QWindow::modality** .
        """
        ...

    def isTopLevel(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwindow.html#isTopLevel

        **bool QWindow::isTopLevel() const**

        Returns whether the window is top level, i.e. has no parent window.
        """
        ...

    def setParent(self, parent: "QWindow") -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setParent

        **void QWindow::setParent(QWindow * parent )**

        Sets the **parent** Window. This will lead to the windowing system
        managing the clip of the window, so it will be clipped to the **parent**
        window.

        Setting **parent** to be `nullptr` will make the window become a top
        level window.

        If **parent** is a window created by **fromWinId** (), then the current
        window will be embedded inside **parent** , if the platform supports it.

        **See also** **parent** ().
        """
        ...

    def parent(self, mode: "QWindow.AncestorMode" = ...) -> "QWindow":
        """
        https://doc.qt.io/qt-6/qwindow.html#parent

        **[since 5.9] QWindow *QWindow::parent(QWindow::AncestorMode mode =
        ExcludeTransients) const**

        Returns the parent window, if any.

        If **mode** is **IncludeTransients** , then the transient parent is
        returned if there is no parent.

        A window without a parent is known as a top level window.

        This function was introduced in Qt 5.9.

        **See also** **setParent** ().
        """
        ...

    def winId(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qwindow.html#winId

        **WId QWindow::winId() const**

        Returns the window's platform id.

        For platforms where this id might be useful, the value returned will
        uniquely represent the window inside the corresponding screen.

        **See also** **screen** ().
        """
        ...

    def create(self) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#create

        **void QWindow::create()**

        Allocates the platform resources associated with the window.

        It is at this point that the surface format set using **setFormat** ()
        gets resolved into an actual native surface. However, the window remains
        hidden until **setVisible** () is called.

        Note that it is not usually necessary to call this function directly, as
        it will be implicitly called by **show** (), **setVisible** (), and
        other functions that require access to the platform resources.

        Call **destroy** () to free the platform resources if necessary.

        **See also** **destroy** ().
        """
        ...

    def isVisible(self) -> bool:
        ...

    def surfaceType(self) -> QSurface.SurfaceType:
        """
        https://doc.qt.io/qt-6/qwindow.html#surfaceType

        **[override virtual] QSurface::SurfaceType QWindow::surfaceType()
        const**

        Reimplements: **QSurface::surfaceType() const** .

        Returns the surface type of the window.

        **See also** **setSurfaceType** ().
        """
        ...

    def setSurfaceType(self, surfaceType: QSurface.SurfaceType) -> None:
        """
        https://doc.qt.io/qt-6/qwindow.html#setSurfaceType

        **void QWindow::setSurfaceType(QSurface::SurfaceType surfaceType )**

        Sets the **surfaceType** of the window.

        Specifies whether the window is meant for raster rendering with
        **QBackingStore** , or OpenGL rendering with **QOpenGLContext** .

        The **surfaceType**  will be used when the native surface is created in
        the **create** () function. Calling this function after the native
        surface has been created requires calling **destroy** () and **create**
        () to release the old native surface and create a new one.

        **See also** **surfaceType** (), **QBackingStore** , **QOpenGLContext**
        , **create** (), and **destroy** ().
        """
        ...

    @property
    def activeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def contentOrientationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def focusObjectChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwindow.html#focusObjectChanged

        **[signal] void QWindow::focusObjectChanged(QObject * object )**

        This signal is emitted when the final receiver of events tied to focus
        is changed to **object**.

        **See also** **focusObject** ().
        """
        ...

    @property
    def heightChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def maximumHeightChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def maximumWidthChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def minimumHeightChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def minimumWidthChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def modalityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwindow.html#modalityChanged

        **[signal] void QWindow::modalityChanged(Qt::WindowModality modality )**

        This signal is emitted when the Qwindow::modality property changes to
        **modality**.

        **Note:** Notifier signal for property **modality** .
        """
        ...

    @property
    def opacityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def screenChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwindow.html#screenChanged

        **[signal] void QWindow::screenChanged(QScreen * screen )**

        This signal is emitted when a window's **screen** changes, either by
        being set explicitly with **setScreen** (), or automatically when the
        window's screen is removed.
        """
        ...

    @property
    def transientParentChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def visibilityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def visibleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def widthChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def windowStateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwindow.html#windowStateChanged

        **[signal] void QWindow::windowStateChanged(Qt::WindowState windowState
        )**

        This signal is emitted when the **windowState** changes, either by being
        set explicitly with **setWindowStates** (), or automatically when the
        user clicks one of the titlebar buttons or by other means.
        """
        ...

    @property
    def windowTitleChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def xChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def yChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomAttr(QDomNode):
    """
    https://doc.qt.io/qt-6/qdomattr.html

    **Detailed Description**

    For example, the following piece of XML produces an element with no
    children, but two attributes:

    <link href="http://qt-project.org" color="red" />

    You can access the attributes of an element with code like this:

    **QDomElement**  e;
        //...
        **QDomAttr**  a = e.attributeNode("href");
    cout << **qPrintable** (a.value()) << '\\n';   // prints "http://qt-
    project.org"
        a.setValue("http://qt-project.org/doc"); // change the
    node's attribute
        **QDomAttr**  a2 = e.attributeNode("href");
        cout <<
    **qPrintable** (a2.value()) << '\\n';  // prints "http://qt-project.org/doc"

    This example also shows that changing an attribute received from an element
    changes the attribute of the element. If you do not want to change the value
    of the element's attribute you must use **cloneNode** () to get an
    independent copy of the attribute.

    QDomAttr can return the **name** () and **value** () of an attribute. An
    attribute's value is set with **setValue** (). If **specified** () returns
    true the value was set with **setValue** (). The node this attribute is
    attached to (if any) is returned by **ownerElement** ().

    For further information about the Document Object Model see
    <http://www.w3.org/TR/REC-DOM-Level-1/> and <http://www.w3.org/TR/DOM-
    Level-2-Core/>. For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomattr.html#QDomAttr

        **QDomAttr::QDomAttr()**

        Constructs an empty attribute.
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomAttr") -> None:
        """
        https://doc.qt.io/qt-6/qdomattr.html#QDomAttr-1

        **QDomAttr::QDomAttr(const QDomAttr & x )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomattr.html#nodeType

        **QDomNode::NodeType QDomAttr::nodeType() const**

        Returns **AttributeNode** .
        """
        ...

    def setValue(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomattr.html#setValue

        **void QDomAttr::setValue(const QString & v )**

        Sets the attribute's value to **v**.

        **See also** **value** ().
        """
        ...

    def value(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomattr.html#value

        **QString QDomAttr::value() const**

        Returns the value of the attribute or an empty string if the attribute
        has not been specified.

        **See also** **specified** () and **setValue** ().
        """
        ...

    def ownerElement(self) -> "QDomElement":
        """
        https://doc.qt.io/qt-6/qdomattr.html#ownerElement

        **QDomElement QDomAttr::ownerElement() const**

        Returns the element node this attribute is attached to or a **null
        node**  if this attribute is not attached to any element.
        """
        ...

    def specified(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomattr.html#specified

        **bool QDomAttr::specified() const**

        Returns `true` if the attribute has been set by the user with
        **setValue** (). Returns `false` if the value hasn't been specified or
        set.

        **See also** **setValue** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomattr.html#name

        **QString QDomAttr::name() const**

        Returns the attribute's name.
        """
        ...
